UninitReservedMemory

Struct UninitReservedMemory 

pub struct UninitReservedMemory<const MAX_ITEM_SIZE: usize> { /* private fields */ }
An uninitialized handle to a reserved arena slot.

Obtained from Arena::reserve. Must be initialized via init to produce a usable ReservedMemory.

This type is intentionally !Send and !Sync — it must be initialized on the same thread that reserved it.

Implementations

Source

impl<const MAX_ITEM_SIZE: usize> UninitReservedMemory<MAX_ITEM_SIZE>

pub fn init<O>(self, obj: O) -> ReservedMemory<MAX_ITEM_SIZE>

Initialize the reserved memory.

Panics

If the given object isn’t safe to store in this arena.