Module bytes

Module bytes 

Utilities module to manipulate bytes.

Structs

AccessPolicy
What an access is allowed to do to satisfy a read/write of a Bytes.
Bytes
A buffer similar to Box<[u8]> that supports custom memory alignment and allows trailing uninitialized bytes.
Reader
Configures a read of a Bytes.
SharedAllocationController
Allocation controller that shares a view into another Bytes behind an Arc.
Writer
Configures a mutable access of a Bytes.

Enums

AccessError
Error returned when accessing a Bytes.
AllocationError
Errors that may occur during memory allocation operations.
AllocationProperty
The kind of allocation behind the Bytes type.
SplitError
Error when splitting an allocation.
SplitPolicy
Controls how Bytes::split behaves when the allocation can’t be split in place.
ViewError
Error when taking a view into an allocation.

Traits

AllocationController
Defines how an Allocation can be controlled.