pub struct AccessPolicy { /* private fields */ }Expand description
What an access is allowed to do to satisfy a read/write of a Bytes.
Implementations
Sourceimpl AccessPolicy
impl AccessPolicy
Sourcepub fn allow_copy() -> AccessPolicy
pub fn allow_copy() -> AccessPolicy
Allow allocating/copying a new buffer to satisfy the access (copy-on-read materialization and copy-on-write).
Sourcepub fn zero_copy() -> AccessPolicy
pub fn zero_copy() -> AccessPolicy
Forbid any copy: the access succeeds only if it can be served from already-resident
memory, otherwise it fails with AccessError::WouldCopy.
Sourcepub fn copy_allowed(&self) -> bool
pub fn copy_allowed(&self) -> bool
Whether copying is allowed to satisfy the access.