Module codegen

Module codegen 

Structs

InfoBuilder
KernelExpansion
The information necessary to compile a kernel definition.
KernelIntegrator
The kernel integrator allows you to create a kernel definition based on kernel expansion and kernel settings.
MetadataBuilder
Builder for a serialized metadata struct
ScalarBuilder
ScalarInfo
Information related to a scalar input.
VulkanCompilationOptions
WgpuCompilationOptions

Type Aliases

ScalarValues
Stores the data and type for a scalar arg