#[derive(CubeLaunch)]
{
// Attributes available to this derive:
#[cube]
#[launch]
}
Derive macro to define a cube type that is launched with a kernel
#[derive(CubeLaunch)]
{
// Attributes available to this derive:
#[cube]
#[launch]
}
Derive macro to define a cube type that is launched with a kernel