pub struct Matrix<C: CubeType, S: MatrixScope = Plane> { /* private fields */ }Expand description
A matrix represent a 2D grid of numbers.
They can either be in a row major or a column major format.
Implementations
Sourceimpl<C: CubePrimitive, S: MatrixScope> Matrix<C, S>
impl<C: CubePrimitive, S: MatrixScope> Matrix<C, S>
Sourcepub unsafe fn uninitialized(
ident: MatrixIdent,
m: usize,
n: usize,
k: usize,
layout: MatrixLayout,
) -> Self
pub unsafe fn uninitialized( ident: MatrixIdent, m: usize, n: usize, k: usize, layout: MatrixLayout, ) -> Self
Create a new uninitialized matrix that is going to be used in the matrix-multiply and accumulate function.
Safety
Must be initialized with load or fill before use. Using it without initialization is
undefined behaviour on CUDA, and completely invalid on Vulkan.
You have to declare the shape used for the execution. The shape of the current matrix is determined using the MatrixIdent.
- MatrixIdent::A Shape => (M, K)
MatrixIdent::BShape => (K, N)MatrixIdent::AccumulatorShape => (M, N)
Not all shapes are supported, and the permitted shapes depend on the element type.
Refer to nvidia documentation.
Sourcepub fn from_value(
ident: MatrixIdent,
m: usize,
n: usize,
k: usize,
layout: MatrixLayout,
value: C,
) -> Selfwhere
C: Scalar,
pub fn from_value(
ident: MatrixIdent,
m: usize,
n: usize,
k: usize,
layout: MatrixLayout,
value: C,
) -> Selfwhere
C: Scalar,
Create a new matrix that is going to be used in the
matrix-multiply and accumulate function and is filled with value.
You have to declare the shape used for the execution. The shape of the current matrix is determined using the MatrixIdent.
- MatrixIdent::A Shape => (M, K)
MatrixIdent::BShape => (K, N)MatrixIdent::AccumulatorShape => (M, N)
Not all shapes are supported, and the permitted shapes depend on the element type.
Refer to nvidia documentation.
Sourcepub fn from_slice(
ident: MatrixIdent,
m: usize,
n: usize,
k: usize,
layout: MatrixLayout,
value: &[C],
stride: u32,
) -> Self
pub fn from_slice( ident: MatrixIdent, m: usize, n: usize, k: usize, layout: MatrixLayout, value: &[C], stride: u32, ) -> Self
Create a new matrix that is going to be used in the
matrix-multiply and accumulate function and is loaded from value with stride.
You have to declare the shape used for the execution. The shape of the current matrix is determined using the MatrixIdent.
- MatrixIdent::A Shape => (M, K)
MatrixIdent::BShape => (K, N)MatrixIdent::AccumulatorShape => (M, N)
Not all shapes are supported, and the permitted shapes depend on the element type.
Refer to nvidia documentation.
Sourcepub fn from_tensor(
ident: MatrixIdent,
m: usize,
n: usize,
k: usize,
value: &TensorView<C>,
) -> Self
pub fn from_tensor( ident: MatrixIdent, m: usize, n: usize, k: usize, value: &TensorView<C>, ) -> Self
Create a new matrix that is going to be used in the
matrix-multiply and accumulate function and is loaded from value with stride.
You have to declare the shape used for the execution. The shape of the current matrix is determined using the MatrixIdent.
- MatrixIdent::A Shape => (M, K)
MatrixIdent::BShape => (K, N)MatrixIdent::AccumulatorShape => (M, N)
Not all shapes are supported, and the permitted shapes depend on the element type.
Refer to nvidia documentation.
Sourcepub fn __expand_uninitialized(
scope: &Scope,
ident: MatrixIdent,
m: usize,
n: usize,
k: usize,
layout: <MatrixLayout as CubeType>::ExpandType,
) -> <Self as CubeType>::ExpandType
pub fn __expand_uninitialized( scope: &Scope, ident: MatrixIdent, m: usize, n: usize, k: usize, layout: <MatrixLayout as CubeType>::ExpandType, ) -> <Self as CubeType>::ExpandType
Create a new uninitialized matrix that is going to be used in the matrix-multiply and accumulate function.
Safety
Must be initialized with load or fill before use. Using it without initialization is
undefined behaviour on CUDA, and completely invalid on Vulkan.
You have to declare the shape used for the execution. The shape of the current matrix is determined using the MatrixIdent.
- MatrixIdent::A Shape => (M, K)
MatrixIdent::BShape => (K, N)MatrixIdent::AccumulatorShape => (M, N)
Not all shapes are supported, and the permitted shapes depend on the element type.
Refer to nvidia documentation.
Sourcepub fn __expand_from_value(
scope: &Scope,
ident: MatrixIdent,
m: usize,
n: usize,
k: usize,
layout: <MatrixLayout as CubeType>::ExpandType,
value: <C as CubeType>::ExpandType,
) -> <Self as CubeType>::ExpandTypewhere
C: Scalar,
pub fn __expand_from_value(
scope: &Scope,
ident: MatrixIdent,
m: usize,
n: usize,
k: usize,
layout: <MatrixLayout as CubeType>::ExpandType,
value: <C as CubeType>::ExpandType,
) -> <Self as CubeType>::ExpandTypewhere
C: Scalar,
Create a new matrix that is going to be used in the
matrix-multiply and accumulate function and is filled with value.
You have to declare the shape used for the execution. The shape of the current matrix is determined using the MatrixIdent.
- MatrixIdent::A Shape => (M, K)
MatrixIdent::BShape => (K, N)MatrixIdent::AccumulatorShape => (M, N)
Not all shapes are supported, and the permitted shapes depend on the element type.
Refer to nvidia documentation.
Sourcepub fn __expand_from_slice(
scope: &Scope,
ident: MatrixIdent,
m: usize,
n: usize,
k: usize,
layout: <MatrixLayout as CubeType>::ExpandType,
value: &<[C] as CubeType>::ExpandType,
stride: <u32 as CubeType>::ExpandType,
) -> <Self as CubeType>::ExpandType
pub fn __expand_from_slice( scope: &Scope, ident: MatrixIdent, m: usize, n: usize, k: usize, layout: <MatrixLayout as CubeType>::ExpandType, value: &<[C] as CubeType>::ExpandType, stride: <u32 as CubeType>::ExpandType, ) -> <Self as CubeType>::ExpandType
Create a new matrix that is going to be used in the
matrix-multiply and accumulate function and is loaded from value with stride.
You have to declare the shape used for the execution. The shape of the current matrix is determined using the MatrixIdent.
- MatrixIdent::A Shape => (M, K)
MatrixIdent::BShape => (K, N)MatrixIdent::AccumulatorShape => (M, N)
Not all shapes are supported, and the permitted shapes depend on the element type.
Refer to nvidia documentation.
Sourcepub fn __expand_from_tensor(
scope: &Scope,
ident: MatrixIdent,
m: usize,
n: usize,
k: usize,
value: &<TensorView<C> as CubeType>::ExpandType,
) -> <Self as CubeType>::ExpandType
pub fn __expand_from_tensor( scope: &Scope, ident: MatrixIdent, m: usize, n: usize, k: usize, value: &<TensorView<C> as CubeType>::ExpandType, ) -> <Self as CubeType>::ExpandType
Create a new matrix that is going to be used in the
matrix-multiply and accumulate function and is loaded from value with stride.
You have to declare the shape used for the execution. The shape of the current matrix is determined using the MatrixIdent.
- MatrixIdent::A Shape => (M, K)
MatrixIdent::BShape => (K, N)MatrixIdent::AccumulatorShape => (M, N)
Not all shapes are supported, and the permitted shapes depend on the element type.
Refer to nvidia documentation.