set_polyfill

Function set_polyfill 

pub fn set_polyfill<E: Scalar, N: Size>(_elem: Type)
Change the meaning of the given cube primitive type during compilation.

Warning

To be used for very custom kernels, it would likely lead to a JIT compiler error otherwise.