ArrayBinding

Struct ArrayBinding 

pub struct ArrayBinding<R: Runtime> {
    pub handle: Binding,
    /* private fields */
}
Tensor representation with a reference to the server handle.

Fields

handle: Binding

Implementations

Source

impl<R: Runtime> ArrayBinding<R>

pub unsafe fn from_raw_parts(handle: Handle, length: usize) -> Self

Create a new array handle reference.

Safety

Specifying the wrong length may lead to out-of-bounds reads and writes.

pub unsafe fn from_raw_parts_binding(handle: Binding, length: usize) -> Self

Create a new array handle reference.

Safety

Specifying the wrong length or size, may lead to out-of-bounds reads and writes.

pub fn into_tensor(self) -> TensorBinding<R>

Return the handle as a tensor instead of an array.