pub struct Atomic<Inner: CubePrimitive> {
pub val: Inner,
}Expand description
An atomic numerical type wrapping a normal numeric primitive. Enables the use of atomic operations, while disabling normal operations. In WGSL, this is a separate type - on CUDA/SPIR-V it can theoretically be bitcast to a normal number, but this isn’t recommended.
Fields
val: InnerImplementations
Sourceimpl<Inner: CubePrimitive<Scalar: AtomicNumeric>> Atomic<Inner>
impl<Inner: CubePrimitive<Scalar: AtomicNumeric>> Atomic<Inner>
Sourcepub fn exchange(&self, value: Inner) -> Inner
pub fn exchange(&self, value: Inner) -> Inner
Atomically stores the value into the atomic and returns the old value.
Sourcepub fn fetch_add(&self, value: Inner) -> Inner
pub fn fetch_add(&self, value: Inner) -> Inner
Atomically add a number to the atomic variable. Returns the old value.
Sourcepub fn fetch_sub(&self, value: Inner) -> Inner
pub fn fetch_sub(&self, value: Inner) -> Inner
Atomically subtracts a number from the atomic variable. Returns the old value.
Sourcepub fn fetch_max(&self, value: Inner) -> Inner
pub fn fetch_max(&self, value: Inner) -> Inner
Atomically sets the value of the atomic variable to max(current_value, value). Returns
the old value.
Sourcepub fn fetch_min(&self, value: Inner) -> Inner
pub fn fetch_min(&self, value: Inner) -> Inner
Atomically sets the value of the atomic variable to min(current_value, value). Returns the
old value.
Sourcepub fn __expand_load(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
) -> <Inner as CubeType>::ExpandType
pub fn __expand_load( scope: &Scope, this: &<Self as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
Load the value of the atomic.
Sourcepub fn __expand_store(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
value: <Inner as CubeType>::ExpandType,
)
pub fn __expand_store( scope: &Scope, this: &<Self as CubeType>::ExpandType, value: <Inner as CubeType>::ExpandType, )
Store the value of the atomic.
Sourcepub fn __expand_exchange(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
value: <Inner as CubeType>::ExpandType,
) -> <Inner as CubeType>::ExpandType
pub fn __expand_exchange( scope: &Scope, this: &<Self as CubeType>::ExpandType, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
Atomically stores the value into the atomic and returns the old value.
Sourcepub fn __expand_fetch_add(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
value: <Inner as CubeType>::ExpandType,
) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_add( scope: &Scope, this: &<Self as CubeType>::ExpandType, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
Atomically add a number to the atomic variable. Returns the old value.
Sourcepub fn __expand_fetch_sub(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
value: <Inner as CubeType>::ExpandType,
) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_sub( scope: &Scope, this: &<Self as CubeType>::ExpandType, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
Atomically subtracts a number from the atomic variable. Returns the old value.
Sourcepub fn __expand_fetch_max(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
value: <Inner as CubeType>::ExpandType,
) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_max( scope: &Scope, this: &<Self as CubeType>::ExpandType, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
Atomically sets the value of the atomic variable to max(current_value, value). Returns
the old value.
Sourcepub fn __expand_fetch_min(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
value: <Inner as CubeType>::ExpandType,
) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_min( scope: &Scope, this: &<Self as CubeType>::ExpandType, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
Atomically sets the value of the atomic variable to min(current_value, value). Returns the
old value.
Sourceimpl<Inner: CubePrimitive<Scalar: Int>> Atomic<Inner>
impl<Inner: CubePrimitive<Scalar: Int>> Atomic<Inner>
Sourcepub fn compare_exchange_weak(&self, cmp: Inner, value: Inner) -> Inner
pub fn compare_exchange_weak(&self, cmp: Inner, value: Inner) -> Inner
Compare the value at pointer to cmp and set it to value only if they are the same.
Returns the old value of the pointer before the store.
Tip
Compare the returned value to cmp to determine whether the store was successful.
Sourcepub fn fetch_and(&self, value: Inner) -> Inner
pub fn fetch_and(&self, value: Inner) -> Inner
Executes an atomic bitwise and operation on the atomic variable. Returns the old value.
Sourcepub fn fetch_or(&self, value: Inner) -> Inner
pub fn fetch_or(&self, value: Inner) -> Inner
Executes an atomic bitwise or operation on the atomic variable. Returns the old value.
Sourcepub fn fetch_xor(&self, value: Inner) -> Inner
pub fn fetch_xor(&self, value: Inner) -> Inner
Executes an atomic bitwise xor operation on the atomic variable. Returns the old value.
Sourcepub fn __expand_compare_exchange_weak(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
cmp: <Inner as CubeType>::ExpandType,
value: <Inner as CubeType>::ExpandType,
) -> <Inner as CubeType>::ExpandType
pub fn __expand_compare_exchange_weak( scope: &Scope, this: &<Self as CubeType>::ExpandType, cmp: <Inner as CubeType>::ExpandType, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
Compare the value at pointer to cmp and set it to value only if they are the same.
Returns the old value of the pointer before the store.
Tip
Compare the returned value to cmp to determine whether the store was successful.
Sourcepub fn __expand_fetch_and(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
value: <Inner as CubeType>::ExpandType,
) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_and( scope: &Scope, this: &<Self as CubeType>::ExpandType, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
Executes an atomic bitwise and operation on the atomic variable. Returns the old value.
Sourcepub fn __expand_fetch_or(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
value: <Inner as CubeType>::ExpandType,
) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_or( scope: &Scope, this: &<Self as CubeType>::ExpandType, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
Executes an atomic bitwise or operation on the atomic variable. Returns the old value.
Sourcepub fn __expand_fetch_xor(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
value: <Inner as CubeType>::ExpandType,
) -> <Inner as CubeType>::ExpandType
pub fn __expand_fetch_xor( scope: &Scope, this: &<Self as CubeType>::ExpandType, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType
Executes an atomic bitwise xor operation on the atomic variable. Returns the old value.