NativeExpand

Struct NativeExpand 

pub struct NativeExpand<T: ?Sized> {
    pub expand: Value,
    /* private fields */
}
Expand type of a native GPU type, i.e. scalar primitives, arrays, shared memory.

Fields

expand: Value

Implementations

Source

impl NativeExpand<Barrier>

pub fn __expand_tma_load_1d_method<C1: CubePrimitive, C2: CubePrimitive<Scalar = C1::Scalar>>( &self, scope: &Scope, source: &NativeExpand<TensorMap<C1, Tiled>>, destination: &mut SliceExpand<C2>, x: NativeExpand<i32>, )

Source

impl NativeExpand<Barrier>

pub fn __expand_tma_load_2d_method<C1: CubePrimitive, C2: CubePrimitive<Scalar = C1::Scalar>>( &self, scope: &Scope, source: &NativeExpand<TensorMap<C1, Tiled>>, destination: &mut SliceExpand<C2>, y: NativeExpand<i32>, x: NativeExpand<i32>, )

Source

impl NativeExpand<Barrier>

pub fn __expand_tma_load_3d_method<C1: CubePrimitive, C2: CubePrimitive<Scalar = C1::Scalar>>( &self, scope: &Scope, source: &NativeExpand<TensorMap<C1, Tiled>>, destination: &mut SliceExpand<C2>, z: NativeExpand<i32>, y: NativeExpand<i32>, x: NativeExpand<i32>, )

Source

impl NativeExpand<Barrier>

pub fn __expand_tma_load_4d_method<C1: CubePrimitive, C2: CubePrimitive<Scalar = C1::Scalar>>( &self, scope: &Scope, source: &NativeExpand<TensorMap<C1, Tiled>>, destination: &mut SliceExpand<C2>, w: NativeExpand<i32>, z: NativeExpand<i32>, y: NativeExpand<i32>, x: NativeExpand<i32>, )

Source

impl NativeExpand<Barrier>

pub fn __expand_tma_load_5d_method<C1: CubePrimitive, C2: CubePrimitive<Scalar = C1::Scalar>>( &self, scope: &Scope, source: &NativeExpand<TensorMap<C1, Tiled>>, destination: &mut SliceExpand<C2>, v: NativeExpand<i32>, w: NativeExpand<i32>, z: NativeExpand<i32>, y: NativeExpand<i32>, x: NativeExpand<i32>, )

Source

impl NativeExpand<Barrier>

pub fn __expand_tma_load_im2col_3d_method<C1: CubePrimitive, C2: CubePrimitive<Scalar = C1::Scalar>>( &self, scope: &Scope, source: &NativeExpand<TensorMap<C1, Im2col>>, destination: &mut SliceExpand<C2>, n: NativeExpand<i32>, w: NativeExpand<i32>, c: NativeExpand<i32>, w_offset: NativeExpand<u16>, )

Source

impl NativeExpand<Barrier>

pub fn __expand_tma_load_im2col_4d_method<C1: CubePrimitive, C2: CubePrimitive<Scalar = C1::Scalar>>( &self, scope: &Scope, source: &NativeExpand<TensorMap<C1, Im2col>>, destination: &mut SliceExpand<C2>, n: NativeExpand<i32>, h: NativeExpand<i32>, w: NativeExpand<i32>, c: NativeExpand<i32>, h_offset: NativeExpand<u16>, w_offset: NativeExpand<u16>, )

Source

impl NativeExpand<Barrier>

pub fn __expand_tma_load_im2col_5d_method<C1: CubePrimitive, C2: CubePrimitive<Scalar = C1::Scalar>>( &self, scope: &Scope, source: &NativeExpand<TensorMap<C1, Im2col>>, destination: &mut SliceExpand<C2>, n: NativeExpand<i32>, d: NativeExpand<i32>, h: NativeExpand<i32>, w: NativeExpand<i32>, c: NativeExpand<i32>, d_offset: NativeExpand<u16>, h_offset: NativeExpand<u16>, w_offset: NativeExpand<u16>, )

Source

impl NativeExpand<Barrier>

pub fn __expand_init_manual_method( &self, scope: &Scope, arrival_count: <u32 as CubeType>::ExpandType, )

Initializes a barrier with a given arrival_count. This is the number of times arrive or one of its variants needs to be called before the barrier advances.

If all units in the cube arrive on the barrier, use CUBE_DIM as the arrival count. For other purposes, only a subset may need to arrive.

Note

No synchronization or election is performed, this is raw initialization. For shared barriers ensure only one unit performs the initialization, and synchronize the cube afterwards. There may also be additional synchronization requirements for bulk copy operations, like sync_async_proxy_shared().

pub fn __expand_local(scope: &Scope) -> Self

Create a local barrier object for the current unit. Automatically initialized with an arrival count of 1.

pub fn __expand_shared( scope: &Scope, arrival_count: <u32 as CubeType>::ExpandType, is_elected: <bool as CubeType>::ExpandType, ) -> <Shared<Barrier> as CubeType>::ExpandType

Create a shared memory barrier that can be accesses by all units in the cube. Initialized by the is_elected unit with an arrival count of arrival_count. This is the number of times arrive or one of its variants needs to be called before the barrier advances.

If all units in the cube arrive on the barrier, use CUBE_DIM as the arrival count. For other purposes, only a subset may need to arrive.

pub fn __expand_shared_uninit( scope: &Scope, ) -> <Shared<Barrier> as CubeType>::ExpandType

Create a shared memory barrier that can be accesses by all units in the cube. Only declared, but not initialized.

pub fn __expand_init_manual( scope: &Scope, this: &Self, arrival_count: <u32 as CubeType>::ExpandType, )

Initializes a barrier with a given arrival_count. This is the number of times arrive or one of its variants needs to be called before the barrier advances.

If all units in the cube arrive on the barrier, use CUBE_DIM as the arrival count. For other purposes, only a subset may need to arrive.

Note

No synchronization or election is performed, this is raw initialization. For shared barriers ensure only one unit performs the initialization, and synchronize the cube afterwards. There may also be additional synchronization requirements for bulk copy operations, like sync_async_proxy_shared().

Source

impl NativeExpand<Barrier>

pub fn __expand_memcpy_async_method<C: CubePrimitive>( &self, scope: &Scope, source: &<[C] as CubeType>::ExpandType, destination: &mut <[C] as CubeType>::ExpandType, )

Copy the source slice to destination

Safety

This will try to copy the whole source slice, so make sure source length <= destination length

pub fn __expand_memcpy_async_cooperative_method<C: CubePrimitive>( &self, scope: &Scope, source: &<[C] as CubeType>::ExpandType, destination: &mut <[C] as CubeType>::ExpandType, )

Copy the source slice to destination

Safety

This will try to copy the whole source slice, so make sure source length <= destination length

pub fn __expand_memcpy_async_tx_method<C: CubePrimitive>( &self, scope: &Scope, source: &<[C] as CubeType>::ExpandType, destination: &mut <[C] as CubeType>::ExpandType, )

Copy the source slice to destination. Uses transaction count like TMA, so use with expect_tx or arrive_and_expect_tx.

Safety

This will try to copy the whole source slice, so make sure source length <= destination length

pub fn __expand_memcpy_async<C: CubePrimitive>( scope: &Scope, this: &Self, source: &<[C] as CubeType>::ExpandType, destination: &mut <[C] as CubeType>::ExpandType, )

Copy the source slice to destination

Safety

This will try to copy the whole source slice, so make sure source length <= destination length

pub fn __expand_memcpy_async_cooperative<C: CubePrimitive>( scope: &Scope, this: &Self, source: &<[C] as CubeType>::ExpandType, destination: &mut <[C] as CubeType>::ExpandType, )

Copy the source slice to destination

Safety

This will try to copy the whole source slice, so make sure source length <= destination length

pub fn __expand_memcpy_async_tx<C: CubePrimitive>( scope: &Scope, this: &Self, source: &<[C] as CubeType>::ExpandType, destination: &mut <[C] as CubeType>::ExpandType, )

Copy the source slice to destination. Uses transaction count like TMA, so use with expect_tx or arrive_and_expect_tx.

Safety

This will try to copy the whole source slice, so make sure source length <= destination length

Source

impl NativeExpand<Barrier>

pub fn __expand_arrive_method( &self, scope: &Scope, ) -> <BarrierToken as CubeType>::ExpandType

Arrive at the barrier, decrementing arrival count

pub fn __expand_arrive_and_expect_tx_method( &self, scope: &Scope, arrival_count: <u32 as CubeType>::ExpandType, transaction_count: <u32 as CubeType>::ExpandType, ) -> <BarrierToken as CubeType>::ExpandType

Arrive at the barrier, decrementing arrival count. Additionally increments expected count.

pub fn __expand_expect_tx_method( &self, scope: &Scope, expected_count: <u32 as CubeType>::ExpandType, )

Increments the expected count of the barrier.

pub fn __expand_arrive_and_wait_method(&self, scope: &Scope)

Wait until all data is loaded

pub fn __expand_wait_method( &self, scope: &Scope, token: <BarrierToken as CubeType>::ExpandType, )

Wait at the barrier until all arrivals are done

pub fn __expand_wait_parity_method( &self, scope: &Scope, phase: <u32 as CubeType>::ExpandType, )

Wait at the barrier until the phase is completed. Doesn’t require a token, but needs phase to be managed manually.

pub fn __expand_arrive( scope: &Scope, this: &Self, ) -> <BarrierToken as CubeType>::ExpandType

Arrive at the barrier, decrementing arrival count

pub fn __expand_arrive_and_expect_tx( scope: &Scope, this: &Self, arrival_count: <u32 as CubeType>::ExpandType, transaction_count: <u32 as CubeType>::ExpandType, ) -> <BarrierToken as CubeType>::ExpandType

Arrive at the barrier, decrementing arrival count. Additionally increments expected count.

pub fn __expand_expect_tx( scope: &Scope, this: &Self, expected_count: <u32 as CubeType>::ExpandType, )

Increments the expected count of the barrier.

pub fn __expand_arrive_and_wait(scope: &Scope, this: &Self)

Wait until all data is loaded

pub fn __expand_wait( scope: &Scope, this: &Self, token: <BarrierToken as CubeType>::ExpandType, )

Wait at the barrier until all arrivals are done

pub fn __expand_wait_parity( scope: &Scope, this: &Self, phase: <u32 as CubeType>::ExpandType, )

Wait at the barrier until the phase is completed. Doesn’t require a token, but needs phase to be managed manually.

Source

impl NativeExpand<Barrier>

pub fn __expand_commit_copy_async_method(&self, scope: &Scope)

Makes all previous copy_async operations visible on the barrier. Should be called once after all copies have been dispatched, before reading from the shared memory.

Does not count as an arrive in terms of the barrier arrival count. So arrive or arrive_and_wait should still be called afterwards.

pub fn __expand_commit_copy_async(scope: &Scope, this: &Self)

Makes all previous copy_async operations visible on the barrier. Should be called once after all copies have been dispatched, before reading from the shared memory.

Does not count as an arrive in terms of the barrier arrival count. So arrive or arrive_and_wait should still be called afterwards.

Source

impl<E: CubePrimitive> NativeExpand<Array<E>>

pub fn __expand_len_method(&self, scope: &Scope) -> usize

Obtain the array length

pub fn __expand_len(scope: &Scope, this: &Self) -> usize

Obtain the array length

Source

impl<T: CubePrimitive> NativeExpand<Shared<[T]>>

pub fn __expand_len_method( &self, scope: &Scope, ) -> <usize as CubeType>::ExpandType

pub fn __expand_new_slice(scope: &Scope, len: usize) -> Self

Create a new shared slice.

Safety

Shared memory is always uninitialized by default. Reading uninitialized shared values is undefined behavior.

pub fn __expand_new_aligned_slice( scope: &Scope, len: usize, alignment: usize, ) -> Self

Create a new shared slice with a specified minimum alignment.

Safety

Shared memory is always uninitialized by default. Reading uninitialized shared values is undefined behavior.

pub fn __expand_len( scope: &Scope, this: &Self, ) -> <usize as CubeType>::ExpandType

Source

impl<T: NativeCubeType + ?Sized> NativeExpand<Shared<T>>

pub fn __expand_map_method<U: NativeCubeType + ?Sized>( self, scope: &Scope, map: impl for<'a> FnOnce(&Scope, &'a NativeExpand<T>) -> &'a NativeExpand<U>, ) -> SharedExpand<U>

Source

impl<T: NativeCubeType + ?Sized> NativeExpand<Shared<T>>

pub fn __expand_inner_ref_method<'infer, 'scope>( &'infer self, scope: &'scope Scope, ) -> &'infer <T as CubeType>::ExpandType

pub fn __expand_inner_mut_method<'infer, 'scope>( &'infer mut self, scope: &'scope Scope, ) -> &'infer mut <T as CubeType>::ExpandType

pub fn __expand_inner_ref<'infer, 'scope>( scope: &'scope Scope, this: &'infer Self, ) -> &'infer <T as CubeType>::ExpandType

pub fn __expand_inner_mut<'infer, 'scope>( scope: &'scope Scope, this: &'infer mut Self, ) -> &'infer mut <T as CubeType>::ExpandType

Source

impl<T: NativeCubeType + ?Sized> NativeExpand<Shared<T>>

pub fn __expand_free_method(&self, scope: &Scope)

Frees the shared memory for reuse, if possible on the target runtime.

Safety

Must be used in uniform control flow Must not have any dangling references to this shared memory

pub fn __expand_free(scope: &Scope, this: &Self)

Frees the shared memory for reuse, if possible on the target runtime.

Safety

Must be used in uniform control flow Must not have any dangling references to this shared memory

Source

impl<E: CubePrimitive> NativeExpand<[E]>

pub fn __extract_list(&self, scope: &Scope) -> Value

pub fn __extract_offset(&self, scope: &Scope) -> NativeExpand<usize>

pub fn __extract_length(&self, scope: &Scope) -> NativeExpand<usize>

Source

impl<E: Scalar, N: Size> NativeExpand<[Vector<E, N>]>

pub fn __expand_with_vector_size_method<'infer, N2: Size>( &'infer self, scope: &Scope, ) -> &'infer SliceExpand<Vector<E, N2>>

pub fn __expand_with_vector_size_mut_method<'infer, N2: Size>( &'infer mut self, scope: &Scope, ) -> &'infer mut SliceExpand<Vector<E, N2>>

Source

impl<E: CubePrimitive> NativeExpand<[E]>

pub fn __expand_as_vectorized_method( &self, _: &Scope, ) -> &SliceExpand<Vector<E::Scalar, E::Size>>

pub fn __expand_as_vectorized_mut_method( &mut self, _: &Scope, ) -> &mut SliceExpand<Vector<E::Scalar, E::Size>>

pub fn __expand_downcast_method<T: CubePrimitive>( &self, scope: &Scope, ) -> &SliceExpand<T>

pub fn __expand_downcast_mut_method<T: CubePrimitive>( &mut self, scope: &Scope, ) -> &mut SliceExpand<T>

pub fn __expand_as_ptr_method(&self, scope: &Scope) -> *const NativeExpand<E>

pub fn __expand_as_mut_ptr_method( &mut self, scope: &Scope, ) -> *mut NativeExpand<E>

pub fn __expand_as_mut_unchecked_method( &self, scope: &Scope, ) -> &mut SliceExpand<E>

Source

impl<E: CubePrimitive> NativeExpand<[E]>

pub fn __expand_len_method(&self, scope: &Scope) -> NativeExpand<usize>

Get the length of the slice.

pub fn is_empty(&self, scope: &Scope) -> NativeExpand<bool>

Returns true if the slice is empty.

Source

impl<E: CubePrimitive> NativeExpand<Array<E>>

pub fn __expand_as_slice_method<'infer, 'scope>( &'infer self, scope: &'scope Scope, ) -> &'infer <[E] as CubeType>::ExpandType

pub fn __expand_as_mut_slice_method<'infer, 'scope>( &'infer mut self, scope: &'scope Scope, ) -> &'infer mut <[E] as CubeType>::ExpandType

pub fn __expand_as_slice<'infer, 'scope>( scope: &'scope Scope, this: &'infer Self, ) -> &'infer <[E] as CubeType>::ExpandType

pub fn __expand_as_mut_slice<'infer, 'scope>( scope: &'scope Scope, this: &'infer mut Self, ) -> &'infer mut <[E] as CubeType>::ExpandType

Source

impl<E: CubePrimitive> NativeExpand<Shared<[E]>>

pub fn __expand_as_slice_method<'infer, 'scope>( &'infer self, scope: &'scope Scope, ) -> &'infer <[E] as CubeType>::ExpandType

pub fn __expand_as_mut_slice_method<'infer, 'scope>( &'infer mut self, scope: &'scope Scope, ) -> &'infer mut <[E] as CubeType>::ExpandType

pub fn __expand_as_slice<'infer, 'scope>( scope: &'scope Scope, this: &'infer Self, ) -> &'infer <[E] as CubeType>::ExpandType

pub fn __expand_as_mut_slice<'infer, 'scope>( scope: &'scope Scope, this: &'infer mut Self, ) -> &'infer mut <[E] as CubeType>::ExpandType

Source

impl<E: CubePrimitive> NativeExpand<[E]>

pub fn __expand_copy_from_slice_method( &mut self, scope: &Scope, source: &SliceExpand<E>, )

Source

impl<T: CubePrimitive, K: TensorMapKind> NativeExpand<TensorMap<T, K>>

Source

impl<P: Scalar, N: Size> NativeExpand<Vector<P, N>>

pub fn __expand_extract_method( self, scope: &Scope, index: <usize as CubeType>::ExpandType, ) -> <P as CubeType>::ExpandType

pub fn __expand_insert_method( &mut self, scope: &Scope, index: <usize as CubeType>::ExpandType, value: <P as CubeType>::ExpandType, )

pub fn __expand_extract( scope: &Scope, this: Self, index: <usize as CubeType>::ExpandType, ) -> <P as CubeType>::ExpandType

pub fn __expand_insert( scope: &Scope, this: &mut Self, index: <usize as CubeType>::ExpandType, value: <P as CubeType>::ExpandType, )

Source

impl<P: Scalar, N: Size> NativeExpand<Vector<P, N>>

pub fn __expand_fill_method( self, scope: &Scope, value: <P as CubeType>::ExpandType, ) -> Self

Fill the vector with the given value.

If you want to fill the vector with different values, consider using the index API instead.

let mut vector = Vector::<u32>::empty(2);
vector[0] = 1;
vector[1] = 2;
pub fn __expand_fill( scope: &Scope, this: Self, value: <P as CubeType>::ExpandType, ) -> Self

Fill the vector with the given value.

If you want to fill the vector with different values, consider using the index API instead.

let mut vector = Vector::<u32>::empty(2);
vector[0] = 1;
vector[1] = 2;
Source

impl<P: Scalar, N: Size> NativeExpand<Vector<P, N>>

pub fn size(&self) -> VectorSize

Comptime version of size.

pub fn __expand_size_method(&self, _scope: &Scope) -> VectorSize

Expand method of size.

Source

impl<P: Scalar, N: Size> NativeExpand<Vector<P, N>>

pub fn __expand_equal_method( &self, scope: &Scope, other: &Self, ) -> <Vector<bool, N> as CubeType>::ExpandType

Return a new vector with the element-wise comparison of the first vector being equal to the second vector.

pub fn __expand_equal( scope: &Scope, this: &Self, other: &Self, ) -> <Vector<bool, N> as CubeType>::ExpandType

Return a new vector with the element-wise comparison of the first vector being equal to the second vector.

Source

impl<P: Scalar, N: Size> NativeExpand<Vector<P, N>>

pub fn __expand_not_equal_method( &self, scope: &Scope, other: &Self, ) -> <Vector<bool, N> as CubeType>::ExpandType

Return a new vector with the element-wise comparison of the first vector being not equal to the second vector.

pub fn __expand_not_equal( scope: &Scope, this: &Self, other: &Self, ) -> <Vector<bool, N> as CubeType>::ExpandType

Return a new vector with the element-wise comparison of the first vector being not equal to the second vector.

Source

impl<P: Scalar, N: Size> NativeExpand<Vector<P, N>>

pub fn __expand_less_than_method( &self, scope: &Scope, other: &Self, ) -> <Vector<bool, N> as CubeType>::ExpandType

Return a new vector with the element-wise comparison of the first vector being less than the second vector.

pub fn __expand_less_than( scope: &Scope, this: &Self, other: &Self, ) -> <Vector<bool, N> as CubeType>::ExpandType

Return a new vector with the element-wise comparison of the first vector being less than the second vector.

Source

impl<P: Scalar, N: Size> NativeExpand<Vector<P, N>>

pub fn __expand_greater_than_method( &self, scope: &Scope, other: &Self, ) -> <Vector<bool, N> as CubeType>::ExpandType

Return a new vector with the element-wise comparison of the first vector being greater than the second vector.

pub fn __expand_greater_than( scope: &Scope, this: &Self, other: &Self, ) -> <Vector<bool, N> as CubeType>::ExpandType

Return a new vector with the element-wise comparison of the first vector being greater than the second vector.

Source

impl<P: Scalar, N: Size> NativeExpand<Vector<P, N>>

pub fn __expand_less_equal_method( &self, scope: &Scope, other: &Self, ) -> <Vector<bool, N> as CubeType>::ExpandType

Return a new vector with the element-wise comparison of the first vector being less than or equal to the second vector.

pub fn __expand_less_equal( scope: &Scope, this: &Self, other: &Self, ) -> <Vector<bool, N> as CubeType>::ExpandType

Return a new vector with the element-wise comparison of the first vector being less than or equal to the second vector.

Source

impl<P: Scalar, N: Size> NativeExpand<Vector<P, N>>

pub fn __expand_greater_equal_method( &self, scope: &Scope, other: &Self, ) -> <Vector<bool, N> as CubeType>::ExpandType

Return a new vector with the element-wise comparison of the first vector being greater than or equal to the second vector.

pub fn __expand_greater_equal( scope: &Scope, this: &Self, other: &Self, ) -> <Vector<bool, N> as CubeType>::ExpandType

Return a new vector with the element-wise comparison of the first vector being greater than or equal to the second vector.

Source

impl<N: Size> NativeExpand<Vector<bool, N>>

pub fn __expand_vec_and_method( self, scope: &Scope, other: Self, ) -> <Vector<bool, N> as CubeType>::ExpandType

Return a new vector with the element-wise and of the vectors

pub fn __expand_vec_and( scope: &Scope, this: Self, other: Self, ) -> <Vector<bool, N> as CubeType>::ExpandType

Return a new vector with the element-wise and of the vectors

Source

impl<N: Size> NativeExpand<Vector<bool, N>>

pub fn __expand_or_method( self, scope: &Scope, other: Self, ) -> <Vector<bool, N> as CubeType>::ExpandType

Return a new vector with the element-wise and of the vectors

pub fn __expand_or( scope: &Scope, this: Self, other: Self, ) -> <Vector<bool, N> as CubeType>::ExpandType

Return a new vector with the element-wise and of the vectors

Source

impl<P: CountOnes + Scalar, N: Size> NativeExpand<Vector<P, N>>

pub fn __expand_count_ones_method( self, scope: &Scope, ) -> <Vector<u32, N> as CubeType>::ExpandType

pub fn __expand_count_ones( scope: &Scope, this: Self, ) -> <Vector<u32, N> as CubeType>::ExpandType

Source

impl<Inner: CubePrimitive<Scalar: Numeric>> NativeExpand<Atomic<Inner>>

pub fn __expand_load_method( &self, scope: &Scope, ) -> <Inner as CubeType>::ExpandType

Load the value of the atomic.

pub fn __expand_store_method( &self, scope: &Scope, value: <Inner as CubeType>::ExpandType, )

Store the value of the atomic.

pub fn __expand_swap_method( &self, scope: &Scope, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType

Atomically stores the value into the atomic and returns the old value.

pub fn __expand_fetch_add_method( &self, scope: &Scope, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType

Atomically add a number to the atomic variable. Returns the old value.

pub fn __expand_fetch_sub_method( &self, scope: &Scope, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType

Atomically subtracts a number from the atomic variable. Returns the old value.

pub fn __expand_fetch_max_method( &self, scope: &Scope, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType

Atomically sets the value of the atomic variable to max(current_value, value). Returns the old value.

pub fn __expand_fetch_min_method( &self, scope: &Scope, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType

Atomically sets the value of the atomic variable to min(current_value, value). Returns the old value.

pub fn __expand_load( scope: &Scope, this: &Self, ) -> <Inner as CubeType>::ExpandType

Load the value of the atomic.

pub fn __expand_store( scope: &Scope, this: &Self, value: <Inner as CubeType>::ExpandType, )

Store the value of the atomic.

pub fn __expand_swap( scope: &Scope, this: &Self, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType

Atomically stores the value into the atomic and returns the old value.

pub fn __expand_fetch_add( scope: &Scope, this: &Self, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType

Atomically add a number to the atomic variable. Returns the old value.

pub fn __expand_fetch_sub( scope: &Scope, this: &Self, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType

Atomically subtracts a number from the atomic variable. Returns the old value.

pub fn __expand_fetch_max( scope: &Scope, this: &Self, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType

Atomically sets the value of the atomic variable to max(current_value, value). Returns the old value.

pub fn __expand_fetch_min( scope: &Scope, this: &Self, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType

Atomically sets the value of the atomic variable to min(current_value, value). Returns the old value.

Source

impl<Inner: CubePrimitive<Scalar: Int>> NativeExpand<Atomic<Inner>>

pub fn __expand_compare_exchange_weak_method( &self, scope: &Scope, cmp: <Inner as CubeType>::ExpandType, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType

Compare the value at pointer to cmp and set it to value only if they are the same. Returns the old value of the pointer before the store.

Tip

Compare the returned value to cmp to determine whether the store was successful.

pub fn __expand_fetch_and_method( &self, scope: &Scope, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType

Executes an atomic bitwise and operation on the atomic variable. Returns the old value.

pub fn __expand_fetch_or_method( &self, scope: &Scope, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType

Executes an atomic bitwise or operation on the atomic variable. Returns the old value.

pub fn __expand_fetch_xor_method( &self, scope: &Scope, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType

Executes an atomic bitwise xor operation on the atomic variable. Returns the old value.

pub fn __expand_compare_exchange_weak( scope: &Scope, this: &Self, cmp: <Inner as CubeType>::ExpandType, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType

Compare the value at pointer to cmp and set it to value only if they are the same. Returns the old value of the pointer before the store.

Tip

Compare the returned value to cmp to determine whether the store was successful.

pub fn __expand_fetch_and( scope: &Scope, this: &Self, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType

Executes an atomic bitwise and operation on the atomic variable. Returns the old value.

pub fn __expand_fetch_or( scope: &Scope, this: &Self, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType

Executes an atomic bitwise or operation on the atomic variable. Returns the old value.

pub fn __expand_fetch_xor( scope: &Scope, this: &Self, value: <Inner as CubeType>::ExpandType, ) -> <Inner as CubeType>::ExpandType

Executes an atomic bitwise xor operation on the atomic variable. Returns the old value.

Source

impl<T: ?Sized> NativeExpand<T>

pub fn new(expand: Value) -> Self

Constructs a new NativeExpand.

Source

impl<T: ?Sized> NativeExpand<T>

pub unsafe fn as_type_ref_unchecked<E: ?Sized>(&self) -> &NativeExpand<E>

Casts a reference of this expand element to a different type.

Safety

There’s no guarantee the new type is valid for the Value

pub unsafe fn as_type_mut_unchecked<E: ?Sized>( &mut self, ) -> &mut NativeExpand<E>

Casts a mutable reference of this expand element to a different type.

Safety

There’s no guarantee the new type is valid for the Value

Source

impl<T> NativeExpand<T>

Source

impl<T: Scalar + Into<ConstantValue>> NativeExpand<T>

pub fn from_lit(scope: &Scope, lit: T) -> Self

Create an NativeExpand from a value that is normally a literal.

pub fn constant(&self) -> Option<ConstantValue>

Get the ConstantValue from the variable.

pub fn __expand_into_lit_unchecked_method(self, _scope: &Scope) -> T

Source

impl<E: Int> NativeExpand<E>