pub struct OrderingExpand { /* private fields */ }Trait Implementations
Sourceimpl AsMutExpand for OrderingExpand
impl AsMutExpand for OrderingExpand
fn __expand_ref_mut_method(&mut self, _: &Scope) -> &mut Self
fn __expand_as_mut_method(&mut self, scope: &Scope) -> &mut T
Sourceimpl AsRefExpand for OrderingExpand
impl AsRefExpand for OrderingExpand
fn __expand_ref_method(&self, _: &Scope) -> &Self
fn __expand_as_ref_method(&self, scope: &Scope) -> &T
Sourceimpl Assign for OrderingExpand
impl Assign for OrderingExpand
Sourcefn __expand_assign_method(&mut self, scope: &Scope, value: Self)
fn __expand_assign_method(&mut self, scope: &Scope, value: Self)
Assign
value to self in scope.Sourceimpl CubeDebug for OrderingExpand
impl CubeDebug for OrderingExpand
Sourcefn set_debug_name(&self, scope: &Scope, name: &'static str)
fn set_debug_name(&self, scope: &Scope, name: &'static str)
Set the debug name of this type’s expansion. Should do nothing for types that don’t appear
at runtime
Sourceimpl CubeEnum for OrderingExpand
impl CubeEnum for OrderingExpand
type RuntimeValue = <() as CubeType>::ExpandType
fn discriminant(&self) -> NativeExpand<i32>
Sourcefn runtime_value(self) -> Self::RuntimeValue
fn runtime_value(self) -> Self::RuntimeValue
Return the runtime value of this enum, if only one variant has a value.
Should return () for all other cases.
fn discriminant_of(variant_name: &'static str) -> i32
fn discriminant_of_value(&self, variant_name: &'static str) -> i32
Sourceimpl ExpandTypeClone for OrderingExpand
impl ExpandTypeClone for OrderingExpand
Sourcefn clone_unchecked(&self) -> Self
fn clone_unchecked(&self) -> Self
Unchecked clone that only clones the conceptual runtime value. Should only be used in cases
where each copy is used in a mutually exclusive branch (i.e. match, runtime enums). This is
intentionally separated from Rust’s
Clone semantics and should only be used for the
conceptual expand values, never real data. Using two values in the same branch is undefined
behaviour.Sourceimpl IntoExpand for OrderingExpand
impl IntoExpand for OrderingExpand
type Expand = OrderingExpand
fn into_expand(self, _: &Scope) -> Self
Sourceimpl IntoMut for OrderingExpand
impl IntoMut for OrderingExpand
Sourceimpl RuntimeAssign for OrderingExpand
impl RuntimeAssign for OrderingExpand