pub struct RangeFullExpand {}Trait Implementations
Sourceimpl AsMutExpand for RangeFullExpand
impl AsMutExpand for RangeFullExpand
fn __expand_ref_mut_method(&mut self, _: &Scope) -> &mut Self
fn __expand_as_mut_method(&mut self, scope: &Scope) -> &mut T
Sourceimpl AsRefExpand for RangeFullExpand
impl AsRefExpand for RangeFullExpand
fn __expand_ref_method(&self, _: &Scope) -> &Self
fn __expand_as_ref_method(&self, scope: &Scope) -> &T
Sourceimpl CubeDebug for RangeFullExpand
impl CubeDebug for RangeFullExpand
Sourcefn set_debug_name(&self, scope: &Scope, name: &'static str)
fn set_debug_name(&self, scope: &Scope, name: &'static str)
Set the debug name of this type’s expansion. Should do nothing for types that don’t appear
at runtime
Sourceimpl ExpandTypeClone for RangeFullExpand
impl ExpandTypeClone for RangeFullExpand
Sourcefn clone_unchecked(&self) -> Self
fn clone_unchecked(&self) -> Self
Unchecked clone that only clones the conceptual runtime value. Should only be used in cases
where each copy is used in a mutually exclusive branch (i.e. match, runtime enums). This is
intentionally separated from Rust’s
Clone semantics and should only be used for the
conceptual expand values, never real data. Using two values in the same branch is undefined
behaviour.Sourceimpl<E: CubePrimitive> IndexExpand<RangeFullExpand> for SliceExpand<E>
impl<E: CubePrimitive> IndexExpand<RangeFullExpand> for SliceExpand<E>
type Output = NativeExpand<[E]>
fn __expand_index_method( &self, scope: &Scope, index: RangeFullExpand, ) -> &Self::Output
Sourceimpl<E: CubePrimitive> IndexExpand<RangeFullExpand> for NativeExpand<Array<E>>
impl<E: CubePrimitive> IndexExpand<RangeFullExpand> for NativeExpand<Array<E>>
type Output = NativeExpand<[E]>
fn __expand_index_method( &self, scope: &Scope, index: RangeFullExpand, ) -> &Self::Output
Sourceimpl<E: CubePrimitive> IndexExpand<RangeFullExpand> for TensorExpand<E>
impl<E: CubePrimitive> IndexExpand<RangeFullExpand> for TensorExpand<E>
type Output = NativeExpand<[E]>
fn __expand_index_method( &self, scope: &Scope, index: RangeFullExpand, ) -> &Self::Output
type Output = NativeExpand<[E]>
fn __expand_index_method( &self, scope: &Scope, index: RangeFullExpand, ) -> &Self::Output
Sourceimpl<E: CubePrimitive> IndexMutExpand<RangeFullExpand> for SliceExpand<E>
impl<E: CubePrimitive> IndexMutExpand<RangeFullExpand> for SliceExpand<E>
fn __expand_index_mut_method( &mut self, scope: &Scope, index: RangeFullExpand, ) -> &mut <Self as IndexExpand<RangeFullExpand>>::Output
Sourceimpl<E: CubePrimitive> IndexMutExpand<RangeFullExpand> for NativeExpand<Array<E>>
impl<E: CubePrimitive> IndexMutExpand<RangeFullExpand> for NativeExpand<Array<E>>
fn __expand_index_mut_method( &mut self, scope: &Scope, index: RangeFullExpand, ) -> &mut <Self as IndexExpand<RangeFullExpand>>::Output
Sourceimpl<E: CubePrimitive> IndexMutExpand<RangeFullExpand> for TensorExpand<E>
impl<E: CubePrimitive> IndexMutExpand<RangeFullExpand> for TensorExpand<E>
fn __expand_index_mut_method( &mut self, scope: &Scope, index: RangeFullExpand, ) -> &mut <Self as IndexExpand<RangeFullExpand>>::Output
fn __expand_index_mut_method( &mut self, scope: &Scope, index: RangeFullExpand, ) -> &mut <Self as IndexExpand<RangeFullExpand>>::Output
Sourceimpl IntoExpand for RangeFullExpand
impl IntoExpand for RangeFullExpand
type Expand = RangeFullExpand
fn into_expand(self, _: &Scope) -> Self