pub struct RuntimeCell<T: CubeType> { /* private fields */ }Implementations
Sourceimpl<T: CubePrimitive> RuntimeCell<T>
impl<T: CubePrimitive> RuntimeCell<T>
Sourcepub fn __expand_new(
scope: &Scope,
init: <T as CubeType>::ExpandType,
) -> <Self as CubeType>::ExpandType
pub fn __expand_new( scope: &Scope, init: <T as CubeType>::ExpandType, ) -> <Self as CubeType>::ExpandType
Create a new runtime cell with the given initial value.
Sourcepub fn __expand_store(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
value: <T as CubeType>::ExpandType,
)
pub fn __expand_store( scope: &Scope, this: &<Self as CubeType>::ExpandType, value: <T as CubeType>::ExpandType, )
Store a new value in the cell.
Sourcepub fn __expand_read(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
) -> <T as CubeType>::ExpandType
pub fn __expand_read( scope: &Scope, this: &<Self as CubeType>::ExpandType, ) -> <T as CubeType>::ExpandType
Get the value from the call
Sourcepub fn __expand_consume(
scope: &Scope,
this: <Self as CubeType>::ExpandType,
) -> <T as CubeType>::ExpandType
pub fn __expand_consume( scope: &Scope, this: <Self as CubeType>::ExpandType, ) -> <T as CubeType>::ExpandType
Consume the cell.
Sourceimpl<S: Scalar, N: Size> RuntimeCell<Vector<S, N>>
impl<S: Scalar, N: Size> RuntimeCell<Vector<S, N>>
Sourcepub fn insert(&mut self, index: usize, value: S)
pub fn insert(&mut self, index: usize, value: S)
Store a new value in the cell at the given index.
Sourcepub fn __expand_extract(
scope: &Scope,
this: &mut <Self as CubeType>::ExpandType,
index: <usize as CubeType>::ExpandType,
) -> <S as CubeType>::ExpandType
pub fn __expand_extract( scope: &Scope, this: &mut <Self as CubeType>::ExpandType, index: <usize as CubeType>::ExpandType, ) -> <S as CubeType>::ExpandType
Extract the value in the cell at the given index.
Sourcepub fn __expand_insert(
scope: &Scope,
this: &mut <Self as CubeType>::ExpandType,
index: <usize as CubeType>::ExpandType,
value: <S as CubeType>::ExpandType,
)
pub fn __expand_insert( scope: &Scope, this: &mut <Self as CubeType>::ExpandType, index: <usize as CubeType>::ExpandType, value: <S as CubeType>::ExpandType, )
Store a new value in the cell at the given index.