RuntimeCellExpand

Struct RuntimeCellExpand 

pub struct RuntimeCellExpand<T: CubeType> { /* private fields */ }

Implementations

Source

impl<T: CubePrimitive> RuntimeCellExpand<T>

pub fn __expand_store_method( &self, scope: &Scope, value: <T as CubeType>::ExpandType, )

Store a new value in the cell.

pub fn __expand_read_method(&self, scope: &Scope) -> <T as CubeType>::ExpandType

Get the value from the call

pub fn __expand_consume_method( self, scope: &Scope, ) -> <T as CubeType>::ExpandType

Consume the cell.

pub fn __expand_new(scope: &Scope, init: <T as CubeType>::ExpandType) -> Self

Create a new runtime cell with the given initial value.

pub fn __expand_store( scope: &Scope, this: &Self, value: <T as CubeType>::ExpandType, )

Store a new value in the cell.

pub fn __expand_read(scope: &Scope, this: &Self) -> <T as CubeType>::ExpandType

Get the value from the call

pub fn __expand_consume( scope: &Scope, this: Self, ) -> <T as CubeType>::ExpandType

Consume the cell.

Source

impl<S: Scalar, N: Size> RuntimeCellExpand<Vector<S, N>>

pub fn __expand_extract_method( &mut self, scope: &Scope, index: <usize as CubeType>::ExpandType, ) -> <S as CubeType>::ExpandType

Extract the value in the cell at the given index.

pub fn __expand_insert_method( &mut self, scope: &Scope, index: <usize as CubeType>::ExpandType, value: <S as CubeType>::ExpandType, )

Store a new value in the cell at the given index.

pub fn __expand_extract( scope: &Scope, this: &mut Self, index: <usize as CubeType>::ExpandType, ) -> <S as CubeType>::ExpandType

Extract the value in the cell at the given index.

pub fn __expand_insert( scope: &Scope, this: &mut Self, index: <usize as CubeType>::ExpandType, value: <S as CubeType>::ExpandType, )

Store a new value in the cell at the given index.