Shared

Struct Shared 

pub struct Shared<E: NativeCubeType + ?Sized> { /* private fields */ }

Implementations

Source

impl<T: CubePrimitive> Shared<[T]>

pub fn new_slice(len: usize) -> Self

Create a new shared slice.

Safety

Shared memory is always uninitialized by default. Reading uninitialized shared values is undefined behavior.

pub fn new_aligned_slice(len: usize, alignment: usize) -> Self

Create a new shared slice with a specified minimum alignment.

Safety

Shared memory is always uninitialized by default. Reading uninitialized shared values is undefined behavior.

pub fn len(&self) -> usize

pub fn __expand_new_slice( scope: &Scope, len: usize, ) -> <Self as CubeType>::ExpandType

Create a new shared slice.

Safety

Shared memory is always uninitialized by default. Reading uninitialized shared values is undefined behavior.

pub fn __expand_new_aligned_slice( scope: &Scope, len: usize, alignment: usize, ) -> <Self as CubeType>::ExpandType

Create a new shared slice with a specified minimum alignment.

Safety

Shared memory is always uninitialized by default. Reading uninitialized shared values is undefined behavior.

pub fn __expand_len( scope: &Scope, this: &<Self as CubeType>::ExpandType, ) -> <usize as CubeType>::ExpandType

Source

impl<T: NativeCubeType + ?Sized> Shared<T>

pub fn map<U: NativeCubeType + ?Sized>( self, _map: impl FnOnce(&T) -> &U, ) -> Shared<U>

Source

impl<T: CubePrimitive> Shared<T>

pub fn new() -> Self

Create a new shared object.

Safety

Shared memory is always uninitialized by default. Reading uninitialized shared values is undefined behavior.

pub fn __expand_new(scope: &Scope) -> <Self as CubeType>::ExpandType

Create a new shared object.

Safety

Shared memory is always uninitialized by default. Reading uninitialized shared values is undefined behavior.

Source

impl<T: NativeCubeType + ?Sized> Shared<T>

pub fn inner_ref(&self) -> &T

pub fn inner_mut(&mut self) -> &mut T

pub fn __expand_inner_ref<'infer, 'scope>( scope: &'scope Scope, this: &'infer <Self as CubeType>::ExpandType, ) -> &'infer <T as CubeType>::ExpandType

pub fn __expand_inner_mut<'infer, 'scope>( scope: &'scope Scope, this: &'infer mut <Self as CubeType>::ExpandType, ) -> &'infer mut <T as CubeType>::ExpandType

Source

impl<T: CubePrimitive> Shared<T>

pub fn __expand_default(scope: &Scope) -> <Self as CubeType>::ExpandType

Source

impl<T: NativeCubeType + ?Sized> Shared<T>

pub unsafe fn free(&self)

Frees the shared memory for reuse, if possible on the target runtime.

Safety

Must be used in uniform control flow Must not have any dangling references to this shared memory

pub fn __expand_free(scope: &Scope, this: &<Self as CubeType>::ExpandType)

Frees the shared memory for reuse, if possible on the target runtime.

Safety

Must be used in uniform control flow Must not have any dangling references to this shared memory

Source

impl<E: CubePrimitive> Shared<[E]>

pub fn as_slice(&self) -> &[E]

pub fn as_mut_slice(&mut self) -> &mut [E]

pub fn __expand_as_slice<'infer, 'scope>( scope: &'scope Scope, this: &'infer <Self as CubeType>::ExpandType, ) -> &'infer <[E] as CubeType>::ExpandType

pub fn __expand_as_mut_slice<'infer, 'scope>( scope: &'scope Scope, this: &'infer mut <Self as CubeType>::ExpandType, ) -> &'infer mut <[E] as CubeType>::ExpandType