pub struct TensorBinding {
pub handle: BufferBinding,
pub strides: Strides,
pub shape: Shape,
pub tiling: Tiling,
}Expand description
Tensor representation with a reference to the server handle, the strides and the shape.
Fields
handle: BufferBindingstrides: Stridesshape: Shapetiling: TilingHow many fragments each logical dim is stored as; untiled by default.
The shape and strides stay physical, as on Metadata.
Implementations
Sourceimpl TensorBinding
impl TensorBinding
pub fn size(&self) -> usize
Sourcepub fn required_address_type(&self, elem_size: usize) -> AddressType
pub fn required_address_type(&self, elem_size: usize) -> AddressType
Address type required to fully index this tensor handle, assuming scalar access.
Sourcepub fn with_tiling(self, tiling: Tiling) -> Result<Self, MetadataError>
pub fn with_tiling(self, tiling: Tiling) -> Result<Self, MetadataError>
This binding with tiling labelling its physical dims.
Errors
When tiling does not describe this rank: see Tiling::logical_rank.
Sourceimpl TensorBinding
impl TensorBinding
Sourcepub fn into_tensor_arg(self) -> TensorArg
pub fn into_tensor_arg(self) -> TensorArg
Convert the handle into a tensor argument.
Sourcepub fn into_alias(self, index: usize) -> TensorArg
pub fn into_alias(self, index: usize) -> TensorArg
Convert the handle into a tensor argument.
Sourcepub fn as_alias(&self, index: usize) -> TensorArg
pub fn as_alias(&self, index: usize) -> TensorArg
Convert the handle into a tensor argument.
Sourcepub fn into_buffer_arg(self) -> BufferArg
pub fn into_buffer_arg(self) -> BufferArg
Convert the handle into a buffer argument.
Sourcepub unsafe fn from_raw_parts(
handle: Handle,
strides: Strides,
shape: Shape,
) -> Self
pub unsafe fn from_raw_parts( handle: Handle, strides: Strides, shape: Shape, ) -> Self
Create a handle from raw parts.
Safety
If you provide wrong strides or shapes, it might create undefined behavior caused by out-of-bounds reads and writes.
Sourcepub unsafe fn from_raw_parts_binding(
handle: BufferBinding,
strides: Strides,
shape: Shape,
) -> Self
pub unsafe fn from_raw_parts_binding( handle: BufferBinding, strides: Strides, shape: Shape, ) -> Self
Create a handle from raw parts.
Safety
If you provide wrong strides or shapes, it might create undefined behavior caused by out-of-bounds reads and writes.
pub fn into_copy_descriptor(self, elem_size: usize) -> CopyDescriptor