pub struct TensorMetaExpand {
pub len: <usize as CubeType>::ExpandType,
pub rank: <usize as CubeType>::ExpandType,
}Fields
len: <usize as CubeType>::ExpandTyperank: <usize as CubeType>::ExpandTypeTrait Implementations
Sourceimpl AsMutExpand for TensorMetaExpand
impl AsMutExpand for TensorMetaExpand
fn __expand_ref_mut_method(&mut self, _: &Scope) -> &mut Self
fn __expand_as_mut_method(&mut self, scope: &Scope) -> &mut T
Sourceimpl AsRefExpand for TensorMetaExpand
impl AsRefExpand for TensorMetaExpand
fn __expand_ref_method(&self, _: &Scope) -> &Self
fn __expand_as_ref_method(&self, scope: &Scope) -> &T
Sourceimpl Clone for TensorMetaExpand
impl Clone for TensorMetaExpand
Sourcefn clone(&self) -> TensorMetaExpand
fn clone(&self) -> TensorMetaExpand
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TensorMetaExpand
Sourceimpl CubeDebug for TensorMetaExpand
impl CubeDebug for TensorMetaExpand
Sourcefn set_debug_name(&self, scope: &Scope, name: &'static str)
fn set_debug_name(&self, scope: &Scope, name: &'static str)
Set the debug name of this type’s expansion. Should do nothing for types that don’t appear
at runtime
Sourceimpl ExpandTypeClone for TensorMetaExpand
impl ExpandTypeClone for TensorMetaExpand
Sourcefn clone_unchecked(&self) -> Self
fn clone_unchecked(&self) -> Self
Unchecked clone that only clones the conceptual runtime value. Should only be used in cases
where each copy is used in a mutually exclusive branch (i.e. match, runtime enums). This is
intentionally separated from Rust’s
Clone semantics and should only be used for the
conceptual expand values, never real data. Using two values in the same branch is undefined
behaviour.Sourceimpl IntoExpand for TensorMetaExpand
impl IntoExpand for TensorMetaExpand
type Expand = TensorMetaExpand
fn into_expand(self, _: &Scope) -> Self