IntoMut

Trait IntoMut 

pub trait IntoMut: Sized {
    // Required method
    fn into_mut(self, scope: &Scope) -> Self;
}
Convert an expand type to a version with mutable registers when necessary.

Required Methods

fn into_mut(self, scope: &Scope) -> Self

Convert the variable into a potentially new mutable variable in scope, copying if needed.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoMut for ()

Source

fn into_mut(self, _: &Scope) -> Self

Source

impl IntoMut for bf16

Source

fn into_mut(self, _scope: &Scope) -> Self

Source

impl IntoMut for f16

Source

fn into_mut(self, _scope: &Scope) -> Self

Source

impl IntoMut for f32

Source

fn into_mut(self, _scope: &Scope) -> Self

Source

impl IntoMut for f64

Source

fn into_mut(self, _scope: &Scope) -> Self

Source

impl IntoMut for i8

Source

fn into_mut(self, _scope: &Scope) -> Self

Source

impl IntoMut for i16

Source

fn into_mut(self, _scope: &Scope) -> Self

Source

impl IntoMut for i32

Source

fn into_mut(self, _scope: &Scope) -> Self

Source

impl IntoMut for i64

Source

fn into_mut(self, _scope: &Scope) -> Self

Source

impl IntoMut for isize

Source

fn into_mut(self, _scope: &Scope) -> Self

Source

impl IntoMut for u8

Source

fn into_mut(self, _scope: &Scope) -> Self

Source

impl IntoMut for u16

Source

fn into_mut(self, _scope: &Scope) -> Self

Source

impl IntoMut for u32

Source

fn into_mut(self, _scope: &Scope) -> Self

Source

impl IntoMut for u64

Source

fn into_mut(self, _scope: &Scope) -> Self

Source

impl IntoMut for usize

Source

fn into_mut(self, _scope: &Scope) -> Self

Source

impl<P0: IntoMut, P1: IntoMut, P2: IntoMut, P3: IntoMut, P4: IntoMut, P5: IntoMut, P6: IntoMut, P7: IntoMut, P8: IntoMut, P9: IntoMut, P10: IntoMut, P11: IntoMut> IntoMut for (P0, P1, P2, P3, P4, P5, P6, P7, P8, P9, P10, P11)

Source

fn into_mut(self, scope: &Scope) -> Self

Source

impl<P0: IntoMut, P1: IntoMut, P2: IntoMut, P3: IntoMut, P4: IntoMut, P5: IntoMut, P6: IntoMut, P7: IntoMut, P8: IntoMut, P9: IntoMut, P10: IntoMut> IntoMut for (P0, P1, P2, P3, P4, P5, P6, P7, P8, P9, P10)

Source

fn into_mut(self, scope: &Scope) -> Self

Source

impl<P0: IntoMut, P1: IntoMut, P2: IntoMut, P3: IntoMut, P4: IntoMut, P5: IntoMut, P6: IntoMut, P7: IntoMut, P8: IntoMut, P9: IntoMut> IntoMut for (P0, P1, P2, P3, P4, P5, P6, P7, P8, P9)

Source

fn into_mut(self, scope: &Scope) -> Self

Source

impl<P0: IntoMut, P1: IntoMut, P2: IntoMut, P3: IntoMut, P4: IntoMut, P5: IntoMut, P6: IntoMut, P7: IntoMut, P8: IntoMut> IntoMut for (P0, P1, P2, P3, P4, P5, P6, P7, P8)

Source

fn into_mut(self, scope: &Scope) -> Self

Source

impl<P0: IntoMut, P1: IntoMut, P2: IntoMut, P3: IntoMut, P4: IntoMut, P5: IntoMut, P6: IntoMut, P7: IntoMut> IntoMut for (P0, P1, P2, P3, P4, P5, P6, P7)

Source

fn into_mut(self, scope: &Scope) -> Self

Source

impl<P0: IntoMut, P1: IntoMut, P2: IntoMut, P3: IntoMut, P4: IntoMut, P5: IntoMut, P6: IntoMut> IntoMut for (P0, P1, P2, P3, P4, P5, P6)

Source

fn into_mut(self, scope: &Scope) -> Self

Source

impl<P0: IntoMut, P1: IntoMut, P2: IntoMut, P3: IntoMut, P4: IntoMut, P5: IntoMut> IntoMut for (P0, P1, P2, P3, P4, P5)

Source

fn into_mut(self, scope: &Scope) -> Self

Source

impl<P0: IntoMut, P1: IntoMut, P2: IntoMut, P3: IntoMut, P4: IntoMut> IntoMut for (P0, P1, P2, P3, P4)

Source

fn into_mut(self, scope: &Scope) -> Self

Source

impl<P0: IntoMut, P1: IntoMut, P2: IntoMut, P3: IntoMut> IntoMut for (P0, P1, P2, P3)

Source

fn into_mut(self, scope: &Scope) -> Self

Source

impl<P0: IntoMut, P1: IntoMut, P2: IntoMut> IntoMut for (P0, P1, P2)

Source

fn into_mut(self, scope: &Scope) -> Self

Source

impl<P0: IntoMut, P1: IntoMut> IntoMut for (P0, P1)

Source

fn into_mut(self, scope: &Scope) -> Self

Source

impl<P0: IntoMut> IntoMut for (P0,)

Source

fn into_mut(self, scope: &Scope) -> Self

Source

impl<T: IntoMut> IntoMut for &T

Source

fn into_mut(self, _: &Scope) -> Self

Source

impl<T: IntoMut> IntoMut for &mut T

Source

fn into_mut(self, _: &Scope) -> Self

Source

impl<T: IntoMut> IntoMut for *const T

Source

fn into_mut(self, _: &Scope) -> Self

Source

impl<T: IntoMut> IntoMut for *mut T

Source

fn into_mut(self, _: &Scope) -> Self

Source

impl<T: IntoMut> IntoMut for Option<T>

Source

fn into_mut(self, scope: &Scope) -> Self

Source

impl<T: IntoMut> IntoMut for Vec<T>

Source

fn into_mut(self, scope: &Scope) -> Self

Implementors

Source

impl IntoMut for Im2colExpand

Source

impl IntoMut for Im2colWideExpand

Source

impl IntoMut for InputScalarExpand

Source

impl IntoMut for MatrixLayout

Source

impl IntoMut for OrderingExpand

Source

impl IntoMut for RangeFullExpand

Source

impl IntoMut for TensorMetaExpand

Source

impl IntoMut for TiledExpand

Source

impl<A: CubeType, B: CubeType, CD: CubeType> IntoMut for MmaDefinitionExpand<A, B, CD>

Source

impl<C: CubeType, S: MatrixScope> IntoMut for MatrixExpand<C, S>

Source

impl<C: CubeType> IntoMut for NativeExpand<Array<C>>

Source

impl<E: CubePrimitive, K: TensorMapKind> IntoMut for NativeExpand<TensorMap<E, K>>

Source

impl<E: CubePrimitive> IntoMut for NativeExpand<Box<[E]>>

Source

impl<E: CubePrimitive> IntoMut for SliceExpand<E>

Source

impl<Idx: Scalar> IntoMut for RangeExpand<Idx>

Source

impl<Idx: Scalar> IntoMut for RangeFromExpand<Idx>

Source

impl<Idx: Scalar> IntoMut for RangeInclusiveExpand<Idx>

Source

impl<Idx: Scalar> IntoMut for RangeToExpand<Idx>

Source

impl<Idx: Scalar> IntoMut for RangeToInclusiveExpand<Idx>

Source

impl<K: PartialOrd + Ord, V: IntoMut + Clone> IntoMut for Registry<K, V>

Source

impl<T: CubePrimitive> IntoMut for OwnedTensorExpand<T>

Source

impl<T: CubePrimitive> IntoMut for TensorExpand<T>

Source

impl<T: CubePrimitive> IntoMut for TensorViewBuilderExpand<T>

Source

impl<T: CubePrimitive> IntoMut for TensorViewExpand<T>

Source

impl<T: CubeType> IntoMut for ComptimeCellExpand<T>

Source

impl<T: CubeType> IntoMut for ComptimeOptionExpand<T>

Source

impl<T: CubeType> IntoMut for OptionExpand<T>

Source

impl<T: CubeType> IntoMut for RuntimeCellExpand<T>

Source

impl<T: CubeType> IntoMut for Sequence<T>

Source

impl<T: CubeType> IntoMut for SequenceExpand<T>

Source

impl<T: NativeAssign> IntoMut for NativeExpand<T>

Source

impl<T: NativeCubeType + ?Sized> IntoMut for NativeExpand<Shared<T>>