ReadValue

Trait ReadValue 

pub trait ReadValue {
    // Required method
    fn read_value(&self, scope: &Scope) -> Value;
}
Read a value into registers. Should only be implemented for types that can exist outside of memory like primitives or Array, but not for things like Barrier that must exist behind a pointer.

Required Methods

fn read_value(&self, scope: &Scope) -> Value

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors