pub enum RecvTimeoutError {
Timeout,
Disconnected,
}Expand description
An error returned when failing to receive a message in a method that block/wait for a message for a while, but has a timeout after which it gives up.
Variants
Timeout
No message arrived on the channel before the timeout was reached. The channel is still open.
Disconnected
The channel is closed. Either the sender was dropped before sending any message, or the message has already been extracted from the receiver.