pub struct RecvError;Expand description
An error returned from receiving methods that block/wait until a message is available.
The receive operation can only fail if the corresponding Sender was dropped
before sending any message, or if a message has already been received on the channel.