Module io

Module io 

Input Output utilities.

Modules

read_masked
read_tensor_atomic_checked
read_tensor_atomic_validate
read_tensor_checked
read_tensor_validate

Functions

expand_checked_index_assign
expand_validate_index_assign
read_masked
Returns the value at index in list if condition is true, otherwise returns value.
read_tensor_atomic_checked
Returns the value at index in tensor within bounds.
read_tensor_atomic_validate
Returns the value at index in tensor within bounds.
read_tensor_checked
Returns the value at index in tensor within bounds.
read_tensor_validate
Returns the value at index in tensor within bounds.