pub fn read_tensor_checked<C: CubePrimitive>(
tensor: Tensor<C>,
index: usize,
unroll_factor: usize,
) -> CExpand description
Returns the value at index in tensor within bounds.
pub fn read_tensor_checked<C: CubePrimitive>(
tensor: Tensor<C>,
index: usize,
unroll_factor: usize,
) -> CReturns the value at index in tensor within bounds.