pub fn write_checked<C: CubePrimitive>(list: &mut [C], index: usize, value: C)Expand description
Writes the value only if it is in bounds of the buffer
pub fn write_checked<C: CubePrimitive>(list: &mut [C], index: usize, value: C)Writes the value only if it is in bounds of the buffer