Module write_checked

Module write_checked 

Structs

_C

Functions

expand
Writes the value only if it is in bounds of the buffer

Type Aliases

C
Type to be used as a generic for launch kernel argument.