pub struct PromoteBitwisePass;Trait Implementations
Sourceimpl Pass for PromoteBitwisePass
impl Pass for PromoteBitwisePass
Sourcefn run(
&mut self,
op: Ptr<Operation>,
ctx: &mut Context,
_analyses: &mut AnalysisManager,
) -> Result<PassResult>
fn run( &mut self, op: Ptr<Operation>, ctx: &mut Context, _analyses: &mut AnalysisManager, ) -> Result<PassResult>
Run the pass and return whether the IR changed and which analyses are preserved.
Sourcefn as_pass_manager(&mut self) -> Option<&mut dyn PassManager>
fn as_pass_manager(&mut self) -> Option<&mut dyn PassManager>
If this Pass contains, manages and runs other passes,
get self as a PassManager.
Most passes do not qualify and must not override this method.