pub struct ConstEval;Expand description
Evaluates expressions where both operands are constant and replaces them with simple constant assignments. This can often be applied as a result of assignment merging or constant operand simplification.