pub enum TransformAction {
Ignore,
Replace(Vec<Instruction>),
}Expand description
The action that should be performed on an instruction, returned by IrTransformer::maybe_transform
Variants
Ignore
The transformer doesn’t apply to this instruction
Replace(Vec<Instruction>)
Replace this instruction with one or more other instructions