pub struct Visitor<T>(pub T);Tuple Fields
0: TImplementations
Sourceimpl<T> Visitor<T>
impl<T> Visitor<T>
pub fn visit_instruction( &mut self, inst: &mut Instruction, analyses: &GlobalAnalyses, visit_read: impl FnMut(&mut T, &mut Value), visit_write: impl FnMut(&mut T, &mut Value), )
pub fn visit_out( &mut self, out: &mut Option<Value>, visit_write: impl FnMut(&mut T, &mut Value), )
Sourcepub fn visit_operation(
&mut self,
op: &mut Operation,
analyses: &GlobalAnalyses,
visit_read: impl FnMut(&mut T, &mut Value),
)
pub fn visit_operation( &mut self, op: &mut Operation, analyses: &GlobalAnalyses, visit_read: impl FnMut(&mut T, &mut Value), )
Visit an operation with a set of read and write visitors. Each visitor will be called with each read or written to variable.