pub enum FastMath {
NotNaN,
NotInf,
UnsignedZero,
AllowReciprocal,
AllowContraction,
AllowReassociation,
AllowTransform,
ReducedPrecision,
}Expand description
Unchecked optimizations for float operations. May cause precision differences, or undefined behaviour if the relevant conditions are not followed.
Variants
NotNaN
Assume values are never NaN. If they are, the result is considered undefined behaviour.
NotInf
Assume values are never Inf/-Inf. If they are, the result is considered undefined
behaviour.
UnsignedZero
Ignore sign on zero values.
AllowReciprocal
Allow swapping float division with a reciprocal, even if that swap would change precision.
AllowContraction
Allow contracting float operations into fewer operations, even if the precision could change.
AllowReassociation
Allow reassociation for float operations, even if the precision could change.
AllowTransform
Allow all mathematical transformations for float operations, including contraction and reassociation, even if the precision could change.
ReducedPrecision
Allow using lower precision intrinsics
Implementations