pub struct ProfileTicks { /* private fields */ }Expand description
Start and end point for a profile. Can be turned into a duration.
Implementations
Sourceimpl ProfileTicks
impl ProfileTicks
Sourcepub fn from_start_end(start: Instant, end: Instant) -> ProfileTicks
pub fn from_start_end(start: Instant, end: Instant) -> ProfileTicks
Create a new ProfileTicks from a start and end time.
Sourcepub fn start_duration_since(&self, epoch: Instant) -> Duration
pub fn start_duration_since(&self, epoch: Instant) -> Duration
Get the duration since the epoch start of this ProfileTicks.
Sourcepub fn end_duration_since(&self, epoch: Instant) -> Duration
pub fn end_duration_since(&self, epoch: Instant) -> Duration
Get the duration since the epoch end of this ProfileTicks.