pub fn read_sync<F, T>(f: F) -> Twhere
F: Future<Output = T>,Expand description
Read a future synchronously.
On WASM futures cannot block, so this only succeeds if the future returns immediately.
If you want to handle this error, please use
try_read_sync instead.