pub enum Collective {
CommInit,
AllReduce,
Send,
Recv,
SyncCollective,
}Expand description
A collective operation between the devices of one runtime.
Variants
CommInit
Setting up the communication between a group of devices.
AllReduce
Reducing a buffer across a group of devices.
Send
Sending a buffer to a peer device.
Recv
Receiving a buffer from a peer device.
SyncCollective
Waiting for queued collectives to finish.