pub trait MemoryLayoutPolicy:
Send
+ Sync
+ 'static {
// Required method
fn apply(
&self,
stream_id: StreamId,
descriptors: &[MemoryLayoutDescriptor],
) -> (Handle, Vec<MemoryLayout>);
}Expand description
Defines how the memory layout is determined.
Required Methods
Sourcefn apply(
&self,
stream_id: StreamId,
descriptors: &[MemoryLayoutDescriptor],
) -> (Handle, Vec<MemoryLayout>)
fn apply( &self, stream_id: StreamId, descriptors: &[MemoryLayoutDescriptor], ) -> (Handle, Vec<MemoryLayout>)
Applies the memory layout policy to a list of descriptors.
Returns a vector of MemoryLayout, one per descriptor, with layouts that share a
single Binding.