e4m3

Struct e4m3 

pub struct e4m3(/* private fields */);
A 8-bit floating point type with 4 exponent bits and 3 mantissa bits.

Implementations

Source

impl e4m3

pub const MAX: e4m3

Maximum representable value

pub const MIN: e4m3

Minimum representable value

pub const EPSILON: e4m3

the difference between 1.0 and the next largest representable number.

pub const MIN_POSITIVE: e4m3

Minimum representable value

pub const DIGITS: u32 = F8E4M3::DIGITS

Approximate number of significant digits in base 10

pub const MANTISSA_DIGITS: u32 = F8E4M3::MANTISSA_DIGITS

Number of mantissa digits

pub const MAX_10_EXP: i32 = F8E4M3::MAX_10_EXP

Maximum possible normal power of 10 exponent

pub const MAX_EXP: i32 = F8E4M3::MAX_EXP

Maximum possible normal power of 2 exponent

pub const MIN_10_EXP: i32 = F8E4M3::MIN_10_EXP

Minimum possible normal power of 10 exponent

pub const MIN_EXP: i32 = F8E4M3::MIN_EXP

Minimum possible normal power of 2 exponent

pub const RADIX: u32 = 2

The radix, or base, of the floating-point representation.

pub const NAN: e4m3

nan

pub const ZERO: e4m3

Zero

pub const NEG_ZERO: e4m3

Negative Zero

pub const ONE: e4m3

One

pub const fn from_bits(bits: u8) -> e4m3

Constructs a e4m3 value from the raw bits.

pub const fn from_f32(value: f32) -> e4m3

Constructs a e4m3 value from a 32-bit floating point value.

This operation is lossy. If the 32-bit value is too large to fit, ±∞ will result. NaN values are preserved. Subnormal values that are too tiny to be represented will result in ±0. All other values are truncated and rounded to the nearest representable value.

pub const fn from_f64(value: f64) -> e4m3

Constructs a e4m3 value from a 64-bit floating point value.

This operation is lossy. If the 64-bit value is to large to fit, ±∞ will result. NaN values are preserved. 64-bit subnormal values are too tiny to be represented and result in ±0. Exponents that underflow the minimum exponent will result in subnormals or ±0. All other values are truncated and rounded to the nearest representable value.

pub const fn to_bits(self) -> u8

Converts a e4m3 into the underlying bit representation.

pub const fn to_f32(self) -> f32

Converts a e4m3 value into an f32 value.

This conversion is lossless as all values can be represented exactly in f32.

pub fn is_nan(self) -> bool

check if an e4m3 value is Nan

pub const fn to_f64(self) -> f64

Converts a e4m3 value into an f64 value.

This conversion is lossless as all values can be represented exactly in f64.

pub fn total_cmp(self, other: e4m3) -> Ordering

Compares e4m3 values