pub struct tf32(/* private fields */);Expand description
Implementations
Sourceimpl tf32
impl tf32
Sourcepub const fn from_f32(value: f32) -> tf32
pub const fn from_f32(value: f32) -> tf32
Constructs a tf32 value from a 32-bit floating point value.
This operation is lossy. If the 32-bit value is too large to fit, ±∞ will result. NaN values are preserved. Subnormal values that are too tiny to be represented will result in ±0. All other values are truncated and rounded to the nearest representable value.
Sourcepub const fn from_f64(value: f64) -> tf32
pub const fn from_f64(value: f64) -> tf32
Constructs a tf32 value from a 64-bit floating point value.
This operation is lossy. If the 64-bit value is to large to fit, ±∞ will result. NaN values are preserved. 64-bit subnormal values are too tiny to be represented and result in ±0. Exponents that underflow the minimum exponent will result in subnormals or ±0. All other values are truncated and rounded to the nearest representable value.