pub struct RwLock<T> { /* private fields */ }Expand description
A reader-writer lock which is exclusively locked for writing or shared for reading.
This reader-writer lock will block threads waiting for the lock to become available.
The lock can also be statically initialized or created via a RwLock::new
RwLock wrapper to make spin::RwLock API compatible with std::sync::RwLock to swap
Implementations
Sourceimpl<T> RwLock<T>
impl<T> RwLock<T>
Sourcepub const fn new(value: T) -> RwLock<T>
pub const fn new(value: T) -> RwLock<T>
Creates a new reader-writer lock in an unlocked state ready for use.
Sourcepub fn read(&self) -> Result<RwLockReadGuard<'_, T>, String>
pub fn read(&self) -> Result<RwLockReadGuard<'_, T>, String>
Locks this rwlock with shared read access, blocking the current thread until it can be acquired.
Sourcepub fn write(&self) -> Result<RwLockWriteGuard<'_, T>, String>
pub fn write(&self) -> Result<RwLockWriteGuard<'_, T>, String>
Locks this rwlock with exclusive write access, blocking the current thread until it can be acquired.