pub struct ThroughputBenchmarker { /* private fields */ }Expand description
A marker for measuring throughput of compute kernels.
Implementations
Sourceimpl ThroughputBenchmarker
impl ThroughputBenchmarker
Sourcepub fn new(cache: Arc<Mutex<ThroughputCache>>) -> ThroughputBenchmarker
pub fn new(cache: Arc<Mutex<ThroughputCache>>) -> ThroughputBenchmarker
Creates a new ThroughputBenchmarker with the given cache.
Sourcepub fn measure<R>(
&mut self,
client: &ComputeClient<R>,
key: ThroughputKey,
kernel_config: KernelConfig,
) -> ThroughputValuewhere
R: Runtime,
pub fn measure<R>(
&mut self,
client: &ComputeClient<R>,
key: ThroughputKey,
kernel_config: KernelConfig,
) -> ThroughputValuewhere
R: Runtime,
Measure the maximum compute throughput of the given kernel on the given client. Warms up the kernel until it plateaus, then measures the throughput over multiple iterations taking the minimum time per iteration (peak attained).