pub struct ThroughputValue {
pub ops_count: usize,
pub duration: Duration,
}Expand description
Represents the throughput of a computation, including the number of operations and the duration.
Fields
ops_count: usizeThe number of operations performed depending of the mode during the computation.
duration: DurationThe duration of the computation.
Implementations
Sourceimpl ThroughputValue
impl ThroughputValue
Sourcepub const ZERO: ThroughputValue
pub const ZERO: ThroughputValue
A zero-initialized throughput value, representing no operations or duration.
Sourcepub fn bytes_per_s(&self, key: &ThroughputKey) -> f64
pub fn bytes_per_s(&self, key: &ThroughputKey) -> f64
Returns the bytes per second.
Sourcepub fn format(&self, key: &ThroughputKey) -> String
pub fn format(&self, key: &ThroughputKey) -> String
Formats the throughput value as a clean human-readable string.