pub struct AutotuneLogContext {
pub bounds: Option<Bounds>,
pub limit: Option<Duration>,
pub events: Vec<AutotuneLogEvent>,
pub checks: Option<Vec<CheckResult>>,
}Expand description
The context containing bounds, limits, and events that happened during autotuning.
Fields
bounds: Option<Bounds>Calculated bounds for autotuning.
limit: Option<Duration>The time limit to exceed for early short-circuiting.
events: Vec<AutotuneLogEvent>The chronological list of tuning events.
checks: Option<Vec<CheckResult>>The results of the checks.
Implementations
Sourceimpl AutotuneLogContext
impl AutotuneLogContext
Sourcepub fn new(logger: &mut Logger) -> Option<AutotuneLogContext>
pub fn new(logger: &mut Logger) -> Option<AutotuneLogContext>
Creates a new log context if either the human logger or the machine-readable recorder is enabled. The recorder is independent of the logger, so records are still populated when the logger is disabled.