Utilities module to manipulate bytes.
Structs
- Access
Policy - What an access is allowed to do to satisfy a read/write of a
Bytes. - Bytes
- A buffer similar to
Box<[u8]>that supports custom memory alignment and allows trailing uninitialized bytes. - Reader
- Configures a read of a
Bytes. - Shared
Allocation Controller - Allocation controller that shares a view into another
Bytesbehind anArc. - Writer
- Configures a mutable access of a
Bytes.
Enums
- Access
Error - Error returned when accessing a
Bytes. - Allocation
Error - Errors that may occur during memory allocation operations.
- Allocation
Property - The kind of allocation behind the Bytes type.
- Split
Error - Error when splitting an allocation.
- Split
Policy - Controls how
Bytes::splitbehaves when the allocation can’t be split in place. - View
Error - Error when taking a view into an allocation.
Traits
- Allocation
Controller - Defines how an
Allocationcan be controlled.