Module codegen

Module codegen 

Structs

BufferInfo
Information related to a buffer binding.
Info
Helper to calculate info struct fields
InfoBuilder
KernelExpansion
The information necessary to compile a kernel definition.
KernelIntegrator
The kernel integrator allows you to create a kernel definition based on kernel expansion and kernel settings.
KernelSettings
Metadata
Helper to calculate metadata offsets based on buffer count and position
MetadataBuilder
Builder for a serialized metadata struct
ScalarBuilder
ScalarInfo
Information related to a scalar input.
SizedInfoField
VulkanCompilationOptions
WgpuCompilationOptions

Type Aliases

ScalarValues
Stores the data and type for a scalar arg