Structs
- Buffer
Info - Information related to a buffer binding.
- Info
- Helper to calculate info struct fields
- Info
Builder - Kernel
Expansion - The information necessary to compile a kernel definition.
- Kernel
Integrator - The kernel integrator allows you to create a kernel definition based on kernel expansion and kernel settings.
- Kernel
Settings - Metadata
- Helper to calculate metadata offsets based on buffer count and position
- Metadata
Builder - Builder for a serialized metadata struct
- Scalar
Builder - Scalar
Info - Information related to a scalar input.
- Sized
Info Field - Vulkan
Compilation Options - Wgpu
Compilation Options
Type Aliases
- Scalar
Values - Stores the data and type for a scalar arg