pub struct KernelIntegrator { /* private fields */ }Expand description
The kernel integrator allows you to create a kernel definition based on kernel expansion and kernel settings.
Implementations
Sourceimpl KernelIntegrator
impl KernelIntegrator
Sourcepub fn new(info: KernelExpansion) -> Self
pub fn new(info: KernelExpansion) -> Self
Starts a new compilation.
Sourcepub fn integrate(self, settings: KernelSettings) -> KernelDefinition
pub fn integrate(self, settings: KernelSettings) -> KernelDefinition
Performs the compilation with the provided settings.