KernelLauncher

Struct KernelLauncher 

pub struct KernelLauncher<R: Runtime> {
    pub settings: KernelSettings,
    pub scope: Scope,
    /* private fields */
}
Prepare a kernel for launch.

Fields

settings: KernelSettingsscope: Scope

Implementations

Source

impl<R: Runtime> KernelLauncher<R>

pub fn with_scope<T>(&mut self, fun: impl FnMut(&mut Scope) -> T) -> T

pub fn register_scalar<C: ScalarArgType>(&mut self, scalar: C)

Register a scalar to be launched.

pub fn register_scalar_raw(&mut self, bytes: &[u8], dtype: StorageType)

Register a scalar to be launched from raw data.

pub fn launch<K: CubeKernel>( self, cube_count: CubeCount, kernel: K, client: &ComputeClient<R>, )

Launch the kernel.

pub unsafe fn launch_unchecked<K: CubeKernel>( self, cube_count: CubeCount, kernel: K, client: &ComputeClient<R>, )

Launch the kernel without check bounds.

Safety

The kernel must not:

  • Contain any out of bounds reads or writes. Doing so is immediate UB.
  • Contain any loops that never terminate. These may be optimized away entirely or cause other unpredictable behaviour.
Source

impl<R: Runtime> KernelLauncher<R>

pub fn register_tensor(&mut self, tensor: TensorArg<R>, ty: Type)

Push a new input tensor to the state.

pub fn register_array(&mut self, array: ArrayArg<R>, ty: Type)

Push a new input array to the state.

pub fn register_tensor_map<K: TensorMapKind>( &mut self, map: TensorMapArg<R, K>, ty: Type, )

Push a new tensor to the state.

Source

impl<R: Runtime> KernelLauncher<R>

pub fn new(settings: KernelSettings) -> Self