TensorArg

Enum TensorArg 

pub enum TensorArg<R: Runtime> {
    Handle {
        handle: TensorBinding<R>,
    },
    Alias {
        input_pos: usize,
        strides: Strides,
        shape: Shape,
    },
}
Argument to be used for tensors passed as arguments to kernels.

Variants



Handle

The tensor is passed with a tensor handle.

Fields

handle: TensorBinding<R>

The tensor handle.



Alias

The tensor is aliasing another input tensor.

Fields

input_pos: usize

The position of the input tensor.

strides: Strides
shape: Shape

Implementations

Source

impl<R: Runtime> TensorArg<R>

pub unsafe fn from_raw_parts( handle: Handle, strides: Strides, shape: Shape, ) -> Self

Create a new tensor argument specified with its vectorization factor.

Safety

If you provide wrong strides or shapes, it might create undefined behavior caused by out-of-bound reads and writes.

pub fn into_alias(self, position: usize) -> Self

Create an alias argument.

pub fn size(&self) -> usize

pub fn shape(&self) -> &[usize]

pub fn strides(&self) -> &[usize]

Source

impl<R: Runtime> TensorArg<R>

pub fn into_array_arg(self) -> ArrayArg<R>