Registry

Struct Registry 

pub struct Registry<K, V> { /* private fields */ }
It is similar to a map, but where the keys are stored at comptime, but the values can be runtime variables.

Implementations

Source

impl<K: PartialOrd + Ord + Debug, V: CubeType<ExpandType: Clone> + Clone> Registry<K, V>

pub fn new() -> Self

Create a new registry.

pub fn __expand_new(_: &Scope) -> Registry<K, V::ExpandType>

Expand function of Self::new.

pub fn find<Query: RegistryQuery<K>>(&self, query: Query) -> V

Find an item in the registry.

Notes

If the item isn’t present in the registry, the function will panic.

pub fn find_or_default<Query: RegistryQuery<K>>(&mut self, query: Query) -> V
where V: Default, K: Clone,

Find an item in the registry or return the default value.

pub fn insert<Query: RegistryQuery<K>>(&mut self, query: Query, value: V)

Insert an item in the registry.

pub fn __expand_find<Query: RegistryQuery<K>>( _scope: &Scope, state: Registry<K, V::ExpandType>, key: Query, ) -> V::ExpandType

Expand function of Self::find.

pub fn __expand_find_or_default<Query: RegistryQuery<K>>( _scope: &Scope, state: &mut Registry<K, V::ExpandType>, key: Query, ) -> V::ExpandType
where V::ExpandType: Default, K: Clone,

Expand function of Self::find_or_default.

pub fn __expand_insert<Key: Into<K>>( _scope: &Scope, state: &mut Registry<K, V::ExpandType>, key: Key, value: V::ExpandType, )

Expand function of Self::insert.

Source

impl<K: PartialOrd + Ord + Debug, V: Clone> Registry<K, V>

pub fn __expand_find_method(&self, _scope: &Scope, key: K) -> V

Expand method of Self::find.

pub fn __expand_insert_method(&mut self, _scope: &Scope, key: K, value: V)

Expand method of Self::insert.