pub struct Registry<K, V> { /* private fields */ }Expand description
It is similar to a map, but where the keys are stored at comptime, but the values can be runtime variables.
Implementations
Sourceimpl<K: PartialOrd + Ord + Debug, V: CubeType<ExpandType: Clone> + Clone> Registry<K, V>
impl<K: PartialOrd + Ord + Debug, V: CubeType<ExpandType: Clone> + Clone> Registry<K, V>
Sourcepub fn __expand_new(_: &Scope) -> Registry<K, V::ExpandType>
pub fn __expand_new(_: &Scope) -> Registry<K, V::ExpandType>
Expand function of Self::new.
Sourcepub fn find<Query: RegistryQuery<K>>(&self, query: Query) -> V
pub fn find<Query: RegistryQuery<K>>(&self, query: Query) -> V
Find an item in the registry.
Notes
If the item isn’t present in the registry, the function will panic.
Sourcepub fn find_or_default<Query: RegistryQuery<K>>(&mut self, query: Query) -> V
pub fn find_or_default<Query: RegistryQuery<K>>(&mut self, query: Query) -> V
Find an item in the registry or return the default value.
Sourcepub fn insert<Query: RegistryQuery<K>>(&mut self, query: Query, value: V)
pub fn insert<Query: RegistryQuery<K>>(&mut self, query: Query, value: V)
Insert an item in the registry.
Sourcepub fn __expand_find<Query: RegistryQuery<K>>(
_scope: &Scope,
state: Registry<K, V::ExpandType>,
key: Query,
) -> V::ExpandType
pub fn __expand_find<Query: RegistryQuery<K>>( _scope: &Scope, state: Registry<K, V::ExpandType>, key: Query, ) -> V::ExpandType
Expand function of Self::find.
Sourcepub fn __expand_find_or_default<Query: RegistryQuery<K>>(
_scope: &Scope,
state: &mut Registry<K, V::ExpandType>,
key: Query,
) -> V::ExpandType
pub fn __expand_find_or_default<Query: RegistryQuery<K>>( _scope: &Scope, state: &mut Registry<K, V::ExpandType>, key: Query, ) -> V::ExpandType
Expand function of Self::find_or_default.
Sourcepub fn __expand_insert<Key: Into<K>>(
_scope: &Scope,
state: &mut Registry<K, V::ExpandType>,
key: Key,
value: V::ExpandType,
)
pub fn __expand_insert<Key: Into<K>>( _scope: &Scope, state: &mut Registry<K, V::ExpandType>, key: Key, value: V::ExpandType, )
Expand function of Self::insert.
Sourceimpl<K: PartialOrd + Ord + Debug, V: Clone> Registry<K, V>
impl<K: PartialOrd + Ord + Debug, V: Clone> Registry<K, V>
Sourcepub fn __expand_find_method(&self, _scope: &Scope, key: K) -> V
pub fn __expand_find_method(&self, _scope: &Scope, key: K) -> V
Expand method of Self::find.
Sourcepub fn __expand_insert_method(&mut self, _scope: &Scope, key: K, value: V)
pub fn __expand_insert_method(&mut self, _scope: &Scope, key: K, value: V)
Expand method of Self::insert.