pub struct Shared<E: NativeCubeType + ?Sized> { /* private fields */ }Implementations
Sourcepub fn new_slice(len: usize) -> Self
pub fn new_slice(len: usize) -> Self
Create a new shared slice.
Safety
Shared memory is always uninitialized by default. Reading uninitialized shared values is undefined behavior.
Sourcepub fn new_aligned_slice(len: usize, alignment: usize) -> Self
pub fn new_aligned_slice(len: usize, alignment: usize) -> Self
Create a new shared slice with a specified minimum alignment.
Safety
Shared memory is always uninitialized by default. Reading uninitialized shared values is undefined behavior.
pub fn len(&self) -> usize
Sourcepub fn __expand_new_slice(
scope: &Scope,
len: usize,
) -> <Self as CubeType>::ExpandType
pub fn __expand_new_slice( scope: &Scope, len: usize, ) -> <Self as CubeType>::ExpandType
Create a new shared slice.
Safety
Shared memory is always uninitialized by default. Reading uninitialized shared values is undefined behavior.
Sourcepub fn __expand_new_aligned_slice(
scope: &Scope,
len: usize,
alignment: usize,
) -> <Self as CubeType>::ExpandType
pub fn __expand_new_aligned_slice( scope: &Scope, len: usize, alignment: usize, ) -> <Self as CubeType>::ExpandType
Create a new shared slice with a specified minimum alignment.
Safety
Shared memory is always uninitialized by default. Reading uninitialized shared values is undefined behavior.
pub fn __expand_len( scope: &Scope, this: &<Self as CubeType>::ExpandType, ) -> <usize as CubeType>::ExpandType
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new shared object.
Safety
Shared memory is always uninitialized by default. Reading uninitialized shared values is undefined behavior.
Sourcepub fn __expand_new(scope: &Scope) -> <Self as CubeType>::ExpandType
pub fn __expand_new(scope: &Scope) -> <Self as CubeType>::ExpandType
Create a new shared object.
Safety
Shared memory is always uninitialized by default. Reading uninitialized shared values is undefined behavior.
pub fn inner_ref(&self) -> &T
pub fn inner_mut(&mut self) -> &mut T
pub fn __expand_inner_ref<'infer, 'scope>( scope: &'scope Scope, this: &'infer <Self as CubeType>::ExpandType, ) -> &'infer <T as CubeType>::ExpandType
pub fn __expand_inner_mut<'infer, 'scope>( scope: &'scope Scope, this: &'infer mut <Self as CubeType>::ExpandType, ) -> &'infer mut <T as CubeType>::ExpandType
pub fn __expand_default(scope: &Scope) -> <Self as CubeType>::ExpandType
Sourcepub unsafe fn free(&self)
pub unsafe fn free(&self)
Frees the shared memory for reuse, if possible on the target runtime.
Safety
Must be used in uniform control flow Must not have any dangling references to this shared memory
Sourcepub fn __expand_free(scope: &Scope, this: &<Self as CubeType>::ExpandType)
pub fn __expand_free(scope: &Scope, this: &<Self as CubeType>::ExpandType)
Frees the shared memory for reuse, if possible on the target runtime.
Safety
Must be used in uniform control flow Must not have any dangling references to this shared memory
pub fn as_slice(&self) -> &[E]
pub fn as_mut_slice(&mut self) -> &mut [E]
pub fn __expand_as_slice<'infer, 'scope>( scope: &'scope Scope, this: &'infer <Self as CubeType>::ExpandType, ) -> &'infer <[E] as CubeType>::ExpandType ⓘ
pub fn __expand_as_mut_slice<'infer, 'scope>( scope: &'scope Scope, this: &'infer mut <Self as CubeType>::ExpandType, ) -> &'infer mut <[E] as CubeType>::ExpandType ⓘ