TensorBinding

Struct TensorBinding 

pub struct TensorBinding<R: Runtime> {
    pub handle: BufferBinding,
    pub strides: Strides,
    pub shape: Shape,
    pub runtime: PhantomData<R>,
}
Tensor representation with a reference to the server handle, the strides and the shape.

Fields

handle: BufferBindingstrides: Stridesshape: Shaperuntime: PhantomData<R>

Implementations

Source

impl<R: Runtime> TensorBinding<R>

pub fn size(&self) -> usize

pub fn required_address_type(&self, elem_size: usize) -> AddressType

Address type required to fully index this tensor handle, assuming scalar access.

Source

impl<R: Runtime> TensorBinding<R>

pub fn into_tensor_arg(self) -> TensorArg<R>

Convert the handle into a tensor argument.

pub fn into_alias(self, index: usize) -> TensorArg<R>

Convert the handle into a tensor argument.

pub fn as_alias(&self, index: usize) -> TensorArg<R>

Convert the handle into a tensor argument.

pub fn into_buffer_arg(self) -> BufferArg<R>

Convert the handle into a buffer argument.

pub unsafe fn from_raw_parts( handle: Handle, strides: Strides, shape: Shape, ) -> Self

Create a handle from raw parts.

Safety

If you provide wrong strides or shapes, it might create undefined behavior caused by out-of-bounds reads and writes.

pub unsafe fn from_raw_parts_binding( handle: BufferBinding, strides: Strides, shape: Shape, ) -> Self

Create a handle from raw parts.

Safety

If you provide wrong strides or shapes, it might create undefined behavior caused by out-of-bounds reads and writes.

pub fn into_copy_descriptor(self, elem_size: usize) -> CopyDescriptor