pub struct TensorBinding<R: Runtime> {
pub handle: BufferBinding,
pub strides: Strides,
pub shape: Shape,
pub runtime: PhantomData<R>,
}Expand description
Tensor representation with a reference to the server handle, the strides and the shape.
Fields
handle: BufferBindingstrides: Stridesshape: Shaperuntime: PhantomData<R>Implementations
Sourceimpl<R: Runtime> TensorBinding<R>
impl<R: Runtime> TensorBinding<R>
pub fn size(&self) -> usize
Sourcepub fn required_address_type(&self, elem_size: usize) -> AddressType
pub fn required_address_type(&self, elem_size: usize) -> AddressType
Address type required to fully index this tensor handle, assuming scalar access.
Sourceimpl<R: Runtime> TensorBinding<R>
impl<R: Runtime> TensorBinding<R>
Sourcepub fn into_tensor_arg(self) -> TensorArg<R>
pub fn into_tensor_arg(self) -> TensorArg<R>
Convert the handle into a tensor argument.
Sourcepub fn into_alias(self, index: usize) -> TensorArg<R>
pub fn into_alias(self, index: usize) -> TensorArg<R>
Convert the handle into a tensor argument.
Sourcepub fn as_alias(&self, index: usize) -> TensorArg<R>
pub fn as_alias(&self, index: usize) -> TensorArg<R>
Convert the handle into a tensor argument.
Sourcepub fn into_buffer_arg(self) -> BufferArg<R>
pub fn into_buffer_arg(self) -> BufferArg<R>
Convert the handle into a buffer argument.
Sourcepub unsafe fn from_raw_parts(
handle: Handle,
strides: Strides,
shape: Shape,
) -> Self
pub unsafe fn from_raw_parts( handle: Handle, strides: Strides, shape: Shape, ) -> Self
Create a handle from raw parts.
Safety
If you provide wrong strides or shapes, it might create undefined behavior caused by out-of-bounds reads and writes.
Sourcepub unsafe fn from_raw_parts_binding(
handle: BufferBinding,
strides: Strides,
shape: Shape,
) -> Self
pub unsafe fn from_raw_parts_binding( handle: BufferBinding, strides: Strides, shape: Shape, ) -> Self
Create a handle from raw parts.
Safety
If you provide wrong strides or shapes, it might create undefined behavior caused by out-of-bounds reads and writes.
pub fn into_copy_descriptor(self, elem_size: usize) -> CopyDescriptor