pub struct TensorMapArg<R: Runtime, K: TensorMapKind> {
pub tensor: TensorArg<R>,
pub metadata: TensorMapMeta,
pub _kind: PhantomData<K>,
}Expand description
Grid constant tensor map, currently only maps to CUDA tensormap. May be interleaved or swizzled, but last dimension must be contiguous (since strides don’t include the last dimension).
The tensormap is treated as an opaque type at runtime.
Fields
tensor: TensorArg<R>metadata: TensorMapMeta_kind: PhantomData<K>Implementations
Sourceimpl<R: Runtime, K: TensorMapKind> TensorMapArg<R, K>
impl<R: Runtime, K: TensorMapKind> TensorMapArg<R, K>
pub fn new(args: K::Args, tensor: TensorArg<R>, ty: impl Into<Type>) -> Self
pub fn with_elem_stride(self, elem_stride: Strides) -> Self
pub fn with_interleave(self, interleave: TensorMapInterleave) -> Self
pub fn with_swizzle(self, swizzle: TensorMapSwizzle) -> Self
pub fn with_prefetch(self, prefetch: TensorMapPrefetch) -> Self
pub fn with_nan_fill(self) -> Self