pub struct Vector<P: Scalar, N: Size> { /* private fields */ }Expand description
A contiguous list of elements that supports auto-vectorized operations.
Implementations
Sourceimpl<P: Scalar, N: Size> Vector<P, N>
impl<P: Scalar, N: Size> Vector<P, N>
pub fn __expand_new( scope: &Scope, val: NativeExpand<P>, ) -> NativeExpand<Vector<P, N>>
Sourceimpl<P: Scalar, N: Size> Vector<P, N>
impl<P: Scalar, N: Size> Vector<P, N>
Sourcepub fn vector_size(&self) -> VectorSize
pub fn vector_size(&self) -> VectorSize
Get the length of the current vector.
Sourceimpl<P: Scalar, N: Size> Vector<P, N>
impl<P: Scalar, N: Size> Vector<P, N>
pub fn extract(self, index: usize) -> P
pub fn insert(&mut self, index: usize, value: P)
pub fn __expand_extract( scope: &Scope, this: <Self as CubeType>::ExpandType, index: <usize as CubeType>::ExpandType, ) -> <P as CubeType>::ExpandType
pub fn __expand_insert( scope: &Scope, this: &mut <Self as CubeType>::ExpandType, index: <usize as CubeType>::ExpandType, value: <P as CubeType>::ExpandType, )
Sourceimpl<P: Numeric, N: Size> Vector<P, N>
impl<P: Numeric, N: Size> Vector<P, N>
pub fn min_value() -> Self
pub fn max_value() -> Self
Sourcepub fn from_int(val: i64) -> Self
pub fn from_int(val: i64) -> Self
Create a new constant numeric.
Note: since this must work for both integer and float
only the less expressive of both can be created (int)
If a number with decimals is needed, use Float::new.
This method panics when unexpanded. For creating an element with a val, use the new method of the sub type.
pub fn __expand_min_value(scope: &Scope) -> <Self as CubeType>::ExpandType
pub fn __expand_max_value(scope: &Scope) -> <Self as CubeType>::ExpandType
Sourcepub fn __expand_from_int(
scope: &Scope,
val: <i64 as CubeType>::ExpandType,
) -> <Self as CubeType>::ExpandType
pub fn __expand_from_int( scope: &Scope, val: <i64 as CubeType>::ExpandType, ) -> <Self as CubeType>::ExpandType
Create a new constant numeric.
Note: since this must work for both integer and float
only the less expressive of both can be created (int)
If a number with decimals is needed, use Float::new.
This method panics when unexpanded. For creating an element with a val, use the new method of the sub type.
Sourceimpl<P: Scalar, N: Size> Vector<P, N>
impl<P: Scalar, N: Size> Vector<P, N>
Sourcepub fn fill(self, value: P) -> Self
pub fn fill(self, value: P) -> Self
Fill the vector with the given value.
If you want to fill the vector with different values, consider using the index API instead.
let mut vector = Vector::<u32>::empty(2);
vector[0] = 1;
vector[1] = 2;Sourcepub fn __expand_fill(
scope: &Scope,
this: <Self as CubeType>::ExpandType,
value: <P as CubeType>::ExpandType,
) -> <Self as CubeType>::ExpandType
pub fn __expand_fill( scope: &Scope, this: <Self as CubeType>::ExpandType, value: <P as CubeType>::ExpandType, ) -> <Self as CubeType>::ExpandType
Fill the vector with the given value.
If you want to fill the vector with different values, consider using the index API instead.
let mut vector = Vector::<u32>::empty(2);
vector[0] = 1;
vector[1] = 2;Sourceimpl<P: Scalar, N: Size> Vector<P, N>
impl<P: Scalar, N: Size> Vector<P, N>
pub fn empty() -> Self
pub fn __expand_empty(scope: &Scope) -> <Self as CubeType>::ExpandType
Sourceimpl<P: Scalar + Zeroable, N: Size> Vector<P, N>
impl<P: Scalar + Zeroable, N: Size> Vector<P, N>
pub fn zeroed() -> Self
pub fn __expand_zeroed(scope: &Scope) -> <Self as CubeType>::ExpandType
Sourceimpl<P: Scalar, N: Size> Vector<P, N>
impl<P: Scalar, N: Size> Vector<P, N>
Sourcepub fn size(&self) -> VectorSize
pub fn size(&self) -> VectorSize
Get the number of individual elements a vector contains.
The size is available at comptime and may be used in combination with the comptime macro.
// The if statement is going to be executed at comptime.
if comptime!(vector.size() == 1) {
}Sourcepub fn __expand_size(
scope: &Scope,
element: NativeExpand<Vector<P, N>>,
) -> VectorSize
pub fn __expand_size( scope: &Scope, element: NativeExpand<Vector<P, N>>, ) -> VectorSize
Expand function of size.
Sourceimpl<P: Scalar, N: Size> Vector<P, N>
impl<P: Scalar, N: Size> Vector<P, N>
Sourcepub fn equal(&self, other: &Self) -> Vector<bool, N>
pub fn equal(&self, other: &Self) -> Vector<bool, N>
Return a new vector with the element-wise comparison of the first vector being equal to the second vector.
Sourcepub fn __expand_equal(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
other: &<Self as CubeType>::ExpandType,
) -> <Vector<bool, N> as CubeType>::ExpandType
pub fn __expand_equal( scope: &Scope, this: &<Self as CubeType>::ExpandType, other: &<Self as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType
Return a new vector with the element-wise comparison of the first vector being equal to the second vector.
Sourceimpl<P: Scalar, N: Size> Vector<P, N>
impl<P: Scalar, N: Size> Vector<P, N>
Sourcepub fn not_equal(&self, other: &Self) -> Vector<bool, N>
pub fn not_equal(&self, other: &Self) -> Vector<bool, N>
Return a new vector with the element-wise comparison of the first vector being not equal to the second vector.
Sourcepub fn __expand_not_equal(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
other: &<Self as CubeType>::ExpandType,
) -> <Vector<bool, N> as CubeType>::ExpandType
pub fn __expand_not_equal( scope: &Scope, this: &<Self as CubeType>::ExpandType, other: &<Self as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType
Return a new vector with the element-wise comparison of the first vector being not equal to the second vector.
Sourceimpl<P: Scalar, N: Size> Vector<P, N>
impl<P: Scalar, N: Size> Vector<P, N>
Sourcepub fn less_than(&self, other: &Self) -> Vector<bool, N>
pub fn less_than(&self, other: &Self) -> Vector<bool, N>
Return a new vector with the element-wise comparison of the first vector being less than the second vector.
Sourcepub fn __expand_less_than(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
other: &<Self as CubeType>::ExpandType,
) -> <Vector<bool, N> as CubeType>::ExpandType
pub fn __expand_less_than( scope: &Scope, this: &<Self as CubeType>::ExpandType, other: &<Self as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType
Return a new vector with the element-wise comparison of the first vector being less than the second vector.
Sourceimpl<P: Scalar, N: Size> Vector<P, N>
impl<P: Scalar, N: Size> Vector<P, N>
Sourcepub fn greater_than(&self, other: &Self) -> Vector<bool, N>
pub fn greater_than(&self, other: &Self) -> Vector<bool, N>
Return a new vector with the element-wise comparison of the first vector being greater than the second vector.
Sourcepub fn __expand_greater_than(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
other: &<Self as CubeType>::ExpandType,
) -> <Vector<bool, N> as CubeType>::ExpandType
pub fn __expand_greater_than( scope: &Scope, this: &<Self as CubeType>::ExpandType, other: &<Self as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType
Return a new vector with the element-wise comparison of the first vector being greater than the second vector.
Sourceimpl<P: Scalar, N: Size> Vector<P, N>
impl<P: Scalar, N: Size> Vector<P, N>
Sourcepub fn less_equal(&self, other: &Self) -> Vector<bool, N>
pub fn less_equal(&self, other: &Self) -> Vector<bool, N>
Return a new vector with the element-wise comparison of the first vector being less than or equal to the second vector.
Sourcepub fn __expand_less_equal(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
other: &<Self as CubeType>::ExpandType,
) -> <Vector<bool, N> as CubeType>::ExpandType
pub fn __expand_less_equal( scope: &Scope, this: &<Self as CubeType>::ExpandType, other: &<Self as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType
Return a new vector with the element-wise comparison of the first vector being less than or equal to the second vector.
Sourceimpl<P: Scalar, N: Size> Vector<P, N>
impl<P: Scalar, N: Size> Vector<P, N>
Sourcepub fn greater_equal(&self, other: &Self) -> Vector<bool, N>
pub fn greater_equal(&self, other: &Self) -> Vector<bool, N>
Return a new vector with the element-wise comparison of the first vector being greater than or equal to the second vector.
Sourcepub fn __expand_greater_equal(
scope: &Scope,
this: &<Self as CubeType>::ExpandType,
other: &<Self as CubeType>::ExpandType,
) -> <Vector<bool, N> as CubeType>::ExpandType
pub fn __expand_greater_equal( scope: &Scope, this: &<Self as CubeType>::ExpandType, other: &<Self as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType
Return a new vector with the element-wise comparison of the first vector being greater than or equal to the second vector.
Sourceimpl<N: Size> Vector<bool, N>
impl<N: Size> Vector<bool, N>
Sourcepub fn vec_and(self, other: Self) -> Vector<bool, N>
pub fn vec_and(self, other: Self) -> Vector<bool, N>
Return a new vector with the element-wise and of the vectors
Sourcepub fn __expand_vec_and(
scope: &Scope,
this: <Self as CubeType>::ExpandType,
other: <Self as CubeType>::ExpandType,
) -> <Vector<bool, N> as CubeType>::ExpandType
pub fn __expand_vec_and( scope: &Scope, this: <Self as CubeType>::ExpandType, other: <Self as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType
Return a new vector with the element-wise and of the vectors
Sourceimpl<N: Size> Vector<bool, N>
impl<N: Size> Vector<bool, N>
Sourcepub fn or(self, other: Self) -> Vector<bool, N>
pub fn or(self, other: Self) -> Vector<bool, N>
Return a new vector with the element-wise and of the vectors
Sourcepub fn __expand_or(
scope: &Scope,
this: <Self as CubeType>::ExpandType,
other: <Self as CubeType>::ExpandType,
) -> <Vector<bool, N> as CubeType>::ExpandType
pub fn __expand_or( scope: &Scope, this: <Self as CubeType>::ExpandType, other: <Self as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType
Return a new vector with the element-wise and of the vectors
Sourceimpl<P: CountOnes + Scalar, N: Size> Vector<P, N>
impl<P: CountOnes + Scalar, N: Size> Vector<P, N>
pub fn count_ones(self) -> Vector<u32, N>
pub fn __expand_count_ones( scope: &Scope, this: <Self as CubeType>::ExpandType, ) -> <Vector<u32, N> as CubeType>::ExpandType