Vector

Struct Vector 

pub struct Vector<P: Scalar, N: Size> { /* private fields */ }
A contiguous list of elements that supports auto-vectorized operations.

Implementations

Source

impl<P: Scalar, N: Size> Vector<P, N>

pub fn new(val: P) -> Self

Create a new vector of size 1 using the given value.

pub fn __expand_new( scope: &mut Scope, val: NativeExpand<P>, ) -> NativeExpand<Vector<P, N>>

Source

impl<P: Scalar, N: Size> Vector<P, N>

pub fn vector_size(&self) -> VectorSize

Get the length of the current vector.

Source

impl<P: Numeric, N: Size> Vector<P, N>

pub fn min_value() -> Self

pub fn max_value() -> Self

pub fn from_int(val: i64) -> Self

Create a new constant numeric.

Note: since this must work for both integer and float only the less expressive of both can be created (int) If a number with decimals is needed, use Float::new.

This method panics when unexpanded. For creating an element with a val, use the new method of the sub type.

pub fn __expand_min_value(scope: &mut Scope) -> <Self as CubeType>::ExpandType

pub fn __expand_max_value(scope: &mut Scope) -> <Self as CubeType>::ExpandType

pub fn __expand_from_int( scope: &mut Scope, val: <i64 as CubeType>::ExpandType, ) -> <Self as CubeType>::ExpandType

Source

impl<P: Scalar, N: Size> Vector<P, N>

pub fn fill(self, value: P) -> Self

Fill the vector with the given value.

If you want to fill the vector with different values, consider using the index API instead.

let mut vector = Vector::<u32>::empty(2);
vector[0] = 1;
vector[1] = 2;
pub fn __expand_fill( scope: &mut Scope, this: <Self as CubeType>::ExpandType, value: <P as CubeType>::ExpandType, ) -> <Self as CubeType>::ExpandType

Source

impl<P: Scalar, N: Size> Vector<P, N>

pub fn empty() -> Self

pub fn __expand_empty(scope: &mut Scope) -> <Self as CubeType>::ExpandType

Source

impl<P: Scalar + Zeroable, N: Size> Vector<P, N>

pub fn zeroed() -> Self

pub fn __expand_zeroed(scope: &mut Scope) -> <Self as CubeType>::ExpandType

Source

impl<P: Scalar, N: Size> Vector<P, N>

pub fn size(&self) -> VectorSize

Get the number of individual elements a vector contains.

The size is available at comptime and may be used in combination with the comptime macro.

// The if statement is going to be executed at comptime.
if comptime!(vector.size() == 1) {
}
pub fn __expand_size( scope: &mut Scope, element: NativeExpand<Vector<P, N>>, ) -> VectorSize

Expand function of size.

Source

impl<P: Scalar, N: Size> Vector<P, N>

pub fn equal(self, other: Self) -> Vector<bool, N>

Return a new vector with the element-wise comparison of the first vector being equal to the second vector.

pub fn __expand_equal( scope: &mut Scope, this: <Self as CubeType>::ExpandType, other: <Self as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType

Source

impl<P: Scalar, N: Size> Vector<P, N>

pub fn not_equal(self, other: Self) -> Vector<bool, N>

Return a new vector with the element-wise comparison of the first vector being not equal to the second vector.

pub fn __expand_not_equal( scope: &mut Scope, this: <Self as CubeType>::ExpandType, other: <Self as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType

Source

impl<P: Scalar, N: Size> Vector<P, N>

pub fn less_than(self, other: Self) -> Vector<bool, N>

Return a new vector with the element-wise comparison of the first vector being less than the second vector.

pub fn __expand_less_than( scope: &mut Scope, this: <Self as CubeType>::ExpandType, other: <Self as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType

Source

impl<P: Scalar, N: Size> Vector<P, N>

pub fn greater_than(self, other: Self) -> Vector<bool, N>

Return a new vector with the element-wise comparison of the first vector being greater than the second vector.

pub fn __expand_greater_than( scope: &mut Scope, this: <Self as CubeType>::ExpandType, other: <Self as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType

Source

impl<P: Scalar, N: Size> Vector<P, N>

pub fn less_equal(self, other: Self) -> Vector<bool, N>

Return a new vector with the element-wise comparison of the first vector being less than or equal to the second vector.

pub fn __expand_less_equal( scope: &mut Scope, this: <Self as CubeType>::ExpandType, other: <Self as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType

Source

impl<P: Scalar, N: Size> Vector<P, N>

pub fn greater_equal(self, other: Self) -> Vector<bool, N>

Return a new vector with the element-wise comparison of the first vector being greater than or equal to the second vector.

pub fn __expand_greater_equal( scope: &mut Scope, this: <Self as CubeType>::ExpandType, other: <Self as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType

Source

impl<N: Size> Vector<bool, N>

pub fn and(self, other: Self) -> Vector<bool, N>

Return a new vector with the element-wise and of the vectors

pub fn __expand_and( scope: &mut Scope, this: <Self as CubeType>::ExpandType, other: <Self as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType

Source

impl<N: Size> Vector<bool, N>

pub fn or(self, other: Self) -> Vector<bool, N>

Return a new vector with the element-wise and of the vectors

pub fn __expand_or( scope: &mut Scope, this: <Self as CubeType>::ExpandType, other: <Self as CubeType>::ExpandType, ) -> <Vector<bool, N> as CubeType>::ExpandType

Source

impl<P: CountOnes + Scalar, N: Size> Vector<P, N>

pub fn count_ones(self) -> Vector<u32, N>

pub fn __expand_count_ones( scope: &mut Scope, this: <Self as CubeType>::ExpandType, ) -> <Vector<u32, N> as CubeType>::ExpandType