Future utils with a compatible API for native, non-std and wasm environments.
Modules
- channel
- Channel types shared across environments. Channel types shared across environments.
- reader
- Read async data without having to decorate each function with async notation.
Functions
- block_
on - Block until the future is completed and returns the result.
- spawn_
detached - Spawns a future to run detached. This will use a thread on native, or the browser runtime on WASM.
Type Aliases
- DynFut
- A dynamically typed, boxed, future. Useful for futures that need to ensure they are not capturing any of their inputs.