Modules
- bitwise
- checked_
io - minifloat
- Software fp8 conversion, on
u32bit patterns only so that a backend with no 8- or 16-bit types can still call it on the bits in a word. - saturating
- unroll
- util
u32 bit patterns only so that a backend with no 8- or 16-bit types
can still call it on the bits in a word.