Structs
- Const
Eval - Evaluates expressions where both operands are constant and replaces them with simple constant assignments. This can often be applied as a result of assignment merging or constant operand simplification.
- Const
Operand Simplify - Simplifies certain expressions where one operand is constant.
For example:
out = x * 1toout = x