e5m2

Struct e5m2 

pub struct e5m2(/* private fields */);
A 8-bit floating point type with 5 exponent bits and 2 mantissa bits.

Implementations

Source

impl e5m2

pub const MAX: e5m2

Maximum representable value

pub const MIN: e5m2

Minimum representable value

pub const EPSILON: e5m2

the difference between 1.0 and the next largest representable number.

pub const MIN_POSITIVE: e5m2

Minimum representable value

pub const DIGITS: u32 = F8E5M2::DIGITS

Approximate number of significant digits in base 10

pub const MANTISSA_DIGITS: u32 = F8E5M2::MANTISSA_DIGITS

Number of mantissa digits

pub const MAX_10_EXP: i32 = F8E5M2::MAX_10_EXP

Maximum possible normal power of 10 exponent

pub const MAX_EXP: i32 = F8E5M2::MAX_EXP

Maximum possible normal power of 2 exponent

pub const MIN_10_EXP: i32 = F8E5M2::MIN_10_EXP

Minimum possible normal power of 10 exponent

pub const MIN_EXP: i32 = F8E5M2::MIN_EXP

Minimum possible normal power of 2 exponent

pub const RADIX: u32 = 2

The radix, or base, of the floating-point representation.

pub const NAN: e5m2

nan

pub const ZERO: e5m2

Zero

pub const NEG_ZERO: e5m2

Negative Zero

pub const ONE: e5m2

One

pub const fn from_bits(bits: u8) -> e5m2

Constructs a e5m2 value from the raw bits.

pub const fn from_f32(value: f32) -> e5m2

Constructs a e5m2 value from a 32-bit floating point value.

This operation is lossy. If the 32-bit value is too large to fit, ±∞ will result. NaN values are preserved. Subnormal values that are too tiny to be represented will result in ±0. All other values are truncated and rounded to the nearest representable value.

pub const fn from_f64(value: f64) -> e5m2

Constructs a e5m2 value from a 64-bit floating point value.

This operation is lossy. If the 64-bit value is to large to fit, ±∞ will result. NaN values are preserved. 64-bit subnormal values are too tiny to be represented and result in ±0. Exponents that underflow the minimum exponent will result in subnormals or ±0. All other values are truncated and rounded to the nearest representable value.

pub const fn to_bits(self) -> u8

Converts a e5m2 into the underlying bit representation.

pub fn is_nan(self) -> bool

check if an e5m2 value is Nan

pub const fn to_f32(self) -> f32

Converts a e5m2 value into an f32 value.

This conversion is lossless as all values can be represented exactly in f32.

pub const fn to_f64(self) -> f64

Converts a e5m2 value into an f64 value.

This conversion is lossless as all values can be represented exactly in f64.

pub fn total_cmp(self, other: e5m2) -> Ordering

Compares e5m2 values