Module throughput

Module throughput 

Throughput related utilities.

Structs

CmmaDims
The M, N, and K dimensions of a matrix multiplication.
ComputeCmmaConfig
Configuration for a matrix multiplication (CMMA) operation.
KernelConfig
Configuration and payload for a benchmarkable compute kernel.
ThroughputBenchmarker
A marker for measuring throughput of compute kernels.
ThroughputCache
Caches the ThroughputValue for a given ThroughputKey.
ThroughputKey
Represents a key/configuration used to identify the throughput of a computation.
ThroughputValue
Represents the throughput of a computation, including the number of operations and the duration.

Enums

ThroughputMode
Represents the mode of a throughput computation.

Functions

launch_overhead_or_measure
Returns the cached launch overhead for name, measuring it on a miss.

Type Aliases

AccumulatorType
The element type of the accumulator.